# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

from azure.cli.core import AzCommandsLoader
from azure.cli.core.profiles import register_resource_type
from msrest import Deserializer

from ._help import helps  # pylint: disable=unused-import
from ._client_factory import CUSTOM_MGMT_APPSERVICE


class ContainerappCommandsLoader(AzCommandsLoader):

    def __init__(self, cli_ctx=None):
        from azure.cli.core.commands import CliCommandType
        register_resource_type('latest', CUSTOM_MGMT_APPSERVICE, '2021-03-01')
        from ._client_factory import cf_containerapps
        containerapp_custom = CliCommandType(
            operations_tmpl='azext_workerapp.custom#{}',
            client_factory=cf_containerapps)
        super(ContainerappCommandsLoader, self).__init__(cli_ctx=cli_ctx,
                                                      custom_command_type=containerapp_custom,
                                                      resource_type=CUSTOM_MGMT_APPSERVICE)

        def get_models(cli_ctx):
            from azure.cli.core.profiles import get_sdk
            return get_sdk(cli_ctx, CUSTOM_MGMT_APPSERVICE, 'models')

        cli_ctx.deserializer = Deserializer(
            {k: v for k, v in get_models(cli_ctx).__dict__.items() if isinstance(v, type)})

    def load_command_table(self, args):
        from .commands import load_command_table
        load_command_table(self, args)
        return self.command_table

    def load_arguments(self, command):
        from ._params import load_arguments
        load_arguments(self, command)


COMMAND_LOADER_CLS = ContainerappCommandsLoader
