# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model
from msrest.exceptions import HttpOperationError


class ApiDefinitionInfo(Model):
    """Information about the formal API definition for the app.

    :param url: The URL of the API definition.
    :type url: str
    """

    _attribute_map = {
        'url': {'key': 'url', 'type': 'str'},
    }

    def __init__(self, *, url: str=None, **kwargs) -> None:
        super(ApiDefinitionInfo, self).__init__(**kwargs)
        self.url = url


class ApiManagementConfig(Model):
    """Azure API management (APIM) configuration linked to the app.

    :param id: APIM-Api Identifier.
    :type id: str
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
    }

    def __init__(self, *, id: str=None, **kwargs) -> None:
        super(ApiManagementConfig, self).__init__(**kwargs)
        self.id = id


class AppLogsConfiguration(Model):
    """AppLogsConfiguration.

    :param destination:
    :type destination: str
    :param log_analytics_configuration:
    :type log_analytics_configuration:
     ~azure.mgmt.web.v2021_02_01.models.LogAnalyticsConfiguration
    """

    _attribute_map = {
        'destination': {'key': 'destination', 'type': 'str'},
        'log_analytics_configuration': {'key': 'logAnalyticsConfiguration', 'type': 'LogAnalyticsConfiguration'},
    }

    def __init__(self, *, destination: str=None, log_analytics_configuration=None, **kwargs) -> None:
        super(AppLogsConfiguration, self).__init__(**kwargs)
        self.destination = destination
        self.log_analytics_configuration = log_analytics_configuration


class AppServiceEnvironment(Model):
    """Description of an App Service Environment.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    All required parameters must be populated in order to send to Azure.

    :ivar provisioning_state: Provisioning state of the App Service
     Environment. Possible values include: 'Succeeded', 'Failed', 'Canceled',
     'InProgress', 'Deleting'
    :vartype provisioning_state: str or
     ~azure.mgmt.web.v2021_02_01.models.ProvisioningState
    :ivar status: Current status of the App Service Environment. Possible
     values include: 'Preparing', 'Ready', 'Scaling', 'Deleting'
    :vartype status: str or
     ~azure.mgmt.web.v2021_02_01.models.HostingEnvironmentStatus
    :param virtual_network: Required. Description of the Virtual Network.
    :type virtual_network:
     ~azure.mgmt.web.v2021_02_01.models.VirtualNetworkProfile
    :param internal_load_balancing_mode: Specifies which endpoints to serve
     internally in the Virtual Network for the App Service Environment.
     Possible values include: 'None', 'Web', 'Publishing', 'Web, Publishing'
    :type internal_load_balancing_mode: str or
     ~azure.mgmt.web.v2021_02_01.models.LoadBalancingMode
    :param multi_size: Front-end VM size, e.g. "Medium", "Large".
    :type multi_size: str
    :ivar multi_role_count: Number of front-end instances.
    :vartype multi_role_count: int
    :param ipssl_address_count: Number of IP SSL addresses reserved for the
     App Service Environment.
    :type ipssl_address_count: int
    :param dns_suffix: DNS suffix of the App Service Environment.
    :type dns_suffix: str
    :ivar maximum_number_of_machines: Maximum number of VMs in the App Service
     Environment.
    :vartype maximum_number_of_machines: int
    :param front_end_scale_factor: Scale factor for front-ends.
    :type front_end_scale_factor: int
    :ivar suspended: <code>true</code> if the App Service Environment is
     suspended; otherwise, <code>false</code>. The environment can be
     suspended, e.g. when the management endpoint is no longer available
     (most likely because NSG blocked the incoming traffic).
    :vartype suspended: bool
    :param cluster_settings: Custom settings for changing the behavior of the
     App Service Environment.
    :type cluster_settings:
     list[~azure.mgmt.web.v2021_02_01.models.NameValuePair]
    :param user_whitelisted_ip_ranges: User added ip ranges to whitelist on
     ASE db
    :type user_whitelisted_ip_ranges: list[str]
    :ivar has_linux_workers: Flag that displays whether an ASE has linux
     workers or not
    :vartype has_linux_workers: bool
    :ivar dedicated_host_count: Dedicated Host Count
    :vartype dedicated_host_count: int
    :param zone_redundant: Whether or not this App Service Environment is
     zone-redundant.
    :type zone_redundant: bool
    """

    _validation = {
        'provisioning_state': {'readonly': True},
        'status': {'readonly': True},
        'virtual_network': {'required': True},
        'multi_role_count': {'readonly': True},
        'maximum_number_of_machines': {'readonly': True},
        'suspended': {'readonly': True},
        'has_linux_workers': {'readonly': True},
        'dedicated_host_count': {'readonly': True},
    }

    _attribute_map = {
        'provisioning_state': {'key': 'provisioningState', 'type': 'ProvisioningState'},
        'status': {'key': 'status', 'type': 'HostingEnvironmentStatus'},
        'virtual_network': {'key': 'virtualNetwork', 'type': 'VirtualNetworkProfile'},
        'internal_load_balancing_mode': {'key': 'internalLoadBalancingMode', 'type': 'str'},
        'multi_size': {'key': 'multiSize', 'type': 'str'},
        'multi_role_count': {'key': 'multiRoleCount', 'type': 'int'},
        'ipssl_address_count': {'key': 'ipsslAddressCount', 'type': 'int'},
        'dns_suffix': {'key': 'dnsSuffix', 'type': 'str'},
        'maximum_number_of_machines': {'key': 'maximumNumberOfMachines', 'type': 'int'},
        'front_end_scale_factor': {'key': 'frontEndScaleFactor', 'type': 'int'},
        'suspended': {'key': 'suspended', 'type': 'bool'},
        'cluster_settings': {'key': 'clusterSettings', 'type': '[NameValuePair]'},
        'user_whitelisted_ip_ranges': {'key': 'userWhitelistedIpRanges', 'type': '[str]'},
        'has_linux_workers': {'key': 'hasLinuxWorkers', 'type': 'bool'},
        'dedicated_host_count': {'key': 'dedicatedHostCount', 'type': 'int'},
        'zone_redundant': {'key': 'zoneRedundant', 'type': 'bool'},
    }

    def __init__(self, *, virtual_network, internal_load_balancing_mode=None, multi_size: str=None, ipssl_address_count: int=None, dns_suffix: str=None, front_end_scale_factor: int=None, cluster_settings=None, user_whitelisted_ip_ranges=None, zone_redundant: bool=None, **kwargs) -> None:
        super(AppServiceEnvironment, self).__init__(**kwargs)
        self.provisioning_state = None
        self.status = None
        self.virtual_network = virtual_network
        self.internal_load_balancing_mode = internal_load_balancing_mode
        self.multi_size = multi_size
        self.multi_role_count = None
        self.ipssl_address_count = ipssl_address_count
        self.dns_suffix = dns_suffix
        self.maximum_number_of_machines = None
        self.front_end_scale_factor = front_end_scale_factor
        self.suspended = None
        self.cluster_settings = cluster_settings
        self.user_whitelisted_ip_ranges = user_whitelisted_ip_ranges
        self.has_linux_workers = None
        self.dedicated_host_count = None
        self.zone_redundant = zone_redundant


class Resource(Model):
    """Azure resource. This resource is tracked in Azure Resource Manager.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    All required parameters must be populated in order to send to Azure.

    :ivar id: Resource Id.
    :vartype id: str
    :ivar name: Resource Name.
    :vartype name: str
    :param kind: Kind of resource.
    :type kind: str
    :param location: Required. Resource Location.
    :type location: str
    :ivar type: Resource type.
    :vartype type: str
    :param tags: Resource tags.
    :type tags: dict[str, str]
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'location': {'required': True},
        'type': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'kind': {'key': 'kind', 'type': 'str'},
        'location': {'key': 'location', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'tags': {'key': 'tags', 'type': '{str}'},
    }

    def __init__(self, *, location: str, kind: str=None, tags=None, **kwargs) -> None:
        super(Resource, self).__init__(**kwargs)
        self.id = None
        self.name = None
        self.kind = kind
        self.location = location
        self.type = None
        self.tags = tags


class AppServicePlan(Resource):
    """App Service plan.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    All required parameters must be populated in order to send to Azure.

    :ivar id: Resource Id.
    :vartype id: str
    :ivar name: Resource Name.
    :vartype name: str
    :param kind: Kind of resource.
    :type kind: str
    :param location: Required. Resource Location.
    :type location: str
    :ivar type: Resource type.
    :vartype type: str
    :param tags: Resource tags.
    :type tags: dict[str, str]
    :param worker_tier_name: Target worker tier assigned to the App Service
     plan.
    :type worker_tier_name: str
    :ivar status: App Service plan status. Possible values include: 'Ready',
     'Pending', 'Creating'
    :vartype status: str or ~azure.mgmt.web.v2021_02_01.models.StatusOptions
    :ivar subscription: App Service plan subscription.
    :vartype subscription: str
    :param hosting_environment_profile: Specification for the App Service
     Environment to use for the App Service plan.
    :type hosting_environment_profile:
     ~azure.mgmt.web.v2021_02_01.models.HostingEnvironmentProfile
    :ivar maximum_number_of_workers: Maximum number of instances that can be
     assigned to this App Service plan.
    :vartype maximum_number_of_workers: int
    :ivar geo_region: Geographical location for the App Service plan.
    :vartype geo_region: str
    :param per_site_scaling: If <code>true</code>, apps assigned to this App
     Service plan can be scaled independently.
     If <code>false</code>, apps assigned to this App Service plan will scale
     to all instances of the plan. Default value: False .
    :type per_site_scaling: bool
    :param elastic_scale_enabled: ServerFarm supports ElasticScale. Apps in
     this plan will scale as if the ServerFarm was ElasticPremium sku
    :type elastic_scale_enabled: bool
    :param maximum_elastic_worker_count: Maximum number of total workers
     allowed for this ElasticScaleEnabled App Service Plan
    :type maximum_elastic_worker_count: int
    :ivar number_of_sites: Number of apps assigned to this App Service plan.
    :vartype number_of_sites: int
    :param is_spot: If <code>true</code>, this App Service Plan owns spot
     instances.
    :type is_spot: bool
    :param spot_expiration_time: The time when the server farm expires. Valid
     only if it is a spot server farm.
    :type spot_expiration_time: datetime
    :param free_offer_expiration_time: The time when the server farm free
     offer expires.
    :type free_offer_expiration_time: datetime
    :ivar resource_group: Resource group of the App Service plan.
    :vartype resource_group: str
    :param reserved: If Linux app service plan <code>true</code>,
     <code>false</code> otherwise. Default value: False .
    :type reserved: bool
    :param is_xenon: Obsolete: If Hyper-V container app service plan
     <code>true</code>, <code>false</code> otherwise. Default value: False .
    :type is_xenon: bool
    :param hyper_v: If Hyper-V container app service plan <code>true</code>,
     <code>false</code> otherwise. Default value: False .
    :type hyper_v: bool
    :param target_worker_count: Scaling worker count.
    :type target_worker_count: int
    :param target_worker_size_id: Scaling worker size ID.
    :type target_worker_size_id: int
    :ivar provisioning_state: Provisioning state of the App Service Plan.
     Possible values include: 'Succeeded', 'Failed', 'Canceled', 'InProgress',
     'Deleting'
    :vartype provisioning_state: str or
     ~azure.mgmt.web.v2021_02_01.models.ProvisioningState
    :param kube_environment_profile: Specification for the Kubernetes
     Environment to use for the App Service plan.
    :type kube_environment_profile:
     ~azure.mgmt.web.v2021_02_01.models.KubeEnvironmentProfile
    :param zone_redundant: If <code>true</code>, this App Service Plan will
     perform availability zone balancing.
     If <code>false</code>, this App Service Plan will not perform availability
     zone balancing. Default value: False .
    :type zone_redundant: bool
    :param sku:
    :type sku: ~azure.mgmt.web.v2021_02_01.models.SkuDescription
    :param extended_location:
    :type extended_location:
     ~azure.mgmt.web.v2021_02_01.models.ExtendedLocation
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'location': {'required': True},
        'type': {'readonly': True},
        'status': {'readonly': True},
        'subscription': {'readonly': True},
        'maximum_number_of_workers': {'readonly': True},
        'geo_region': {'readonly': True},
        'number_of_sites': {'readonly': True},
        'resource_group': {'readonly': True},
        'provisioning_state': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'kind': {'key': 'kind', 'type': 'str'},
        'location': {'key': 'location', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'tags': {'key': 'tags', 'type': '{str}'},
        'worker_tier_name': {'key': 'properties.workerTierName', 'type': 'str'},
        'status': {'key': 'properties.status', 'type': 'StatusOptions'},
        'subscription': {'key': 'properties.subscription', 'type': 'str'},
        'hosting_environment_profile': {'key': 'properties.hostingEnvironmentProfile', 'type': 'HostingEnvironmentProfile'},
        'maximum_number_of_workers': {'key': 'properties.maximumNumberOfWorkers', 'type': 'int'},
        'geo_region': {'key': 'properties.geoRegion', 'type': 'str'},
        'per_site_scaling': {'key': 'properties.perSiteScaling', 'type': 'bool'},
        'elastic_scale_enabled': {'key': 'properties.elasticScaleEnabled', 'type': 'bool'},
        'maximum_elastic_worker_count': {'key': 'properties.maximumElasticWorkerCount', 'type': 'int'},
        'number_of_sites': {'key': 'properties.numberOfSites', 'type': 'int'},
        'is_spot': {'key': 'properties.isSpot', 'type': 'bool'},
        'spot_expiration_time': {'key': 'properties.spotExpirationTime', 'type': 'iso-8601'},
        'free_offer_expiration_time': {'key': 'properties.freeOfferExpirationTime', 'type': 'iso-8601'},
        'resource_group': {'key': 'properties.resourceGroup', 'type': 'str'},
        'reserved': {'key': 'properties.reserved', 'type': 'bool'},
        'is_xenon': {'key': 'properties.isXenon', 'type': 'bool'},
        'hyper_v': {'key': 'properties.hyperV', 'type': 'bool'},
        'target_worker_count': {'key': 'properties.targetWorkerCount', 'type': 'int'},
        'target_worker_size_id': {'key': 'properties.targetWorkerSizeId', 'type': 'int'},
        'provisioning_state': {'key': 'properties.provisioningState', 'type': 'ProvisioningState'},
        'kube_environment_profile': {'key': 'properties.kubeEnvironmentProfile', 'type': 'KubeEnvironmentProfile'},
        'zone_redundant': {'key': 'properties.zoneRedundant', 'type': 'bool'},
        'sku': {'key': 'sku', 'type': 'SkuDescription'},
        'extended_location': {'key': 'extendedLocation', 'type': 'ExtendedLocation'},
    }

    def __init__(self, *, location: str, kind: str=None, tags=None, worker_tier_name: str=None, hosting_environment_profile=None, per_site_scaling: bool=False, elastic_scale_enabled: bool=None, maximum_elastic_worker_count: int=None, is_spot: bool=None, spot_expiration_time=None, free_offer_expiration_time=None, reserved: bool=False, is_xenon: bool=False, hyper_v: bool=False, target_worker_count: int=None, target_worker_size_id: int=None, kube_environment_profile=None, zone_redundant: bool=False, sku=None, extended_location=None, **kwargs) -> None:
        super(AppServicePlan, self).__init__(kind=kind, location=location, tags=tags, **kwargs)
        self.worker_tier_name = worker_tier_name
        self.status = None
        self.subscription = None
        self.hosting_environment_profile = hosting_environment_profile
        self.maximum_number_of_workers = None
        self.geo_region = None
        self.per_site_scaling = per_site_scaling
        self.elastic_scale_enabled = elastic_scale_enabled
        self.maximum_elastic_worker_count = maximum_elastic_worker_count
        self.number_of_sites = None
        self.is_spot = is_spot
        self.spot_expiration_time = spot_expiration_time
        self.free_offer_expiration_time = free_offer_expiration_time
        self.resource_group = None
        self.reserved = reserved
        self.is_xenon = is_xenon
        self.hyper_v = hyper_v
        self.target_worker_count = target_worker_count
        self.target_worker_size_id = target_worker_size_id
        self.provisioning_state = None
        self.kube_environment_profile = kube_environment_profile
        self.zone_redundant = zone_redundant
        self.sku = sku
        self.extended_location = extended_location


class AppServicePlanCollection(Model):
    """Collection of App Service plans.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    All required parameters must be populated in order to send to Azure.

    :param value: Required. Collection of resources.
    :type value: list[~azure.mgmt.web.v2021_02_01.models.AppServicePlan]
    :ivar next_link: Link to next page of resources.
    :vartype next_link: str
    """

    _validation = {
        'value': {'required': True},
        'next_link': {'readonly': True},
    }

    _attribute_map = {
        'value': {'key': 'value', 'type': '[AppServicePlan]'},
        'next_link': {'key': 'nextLink', 'type': 'str'},
    }

    def __init__(self, *, value, **kwargs) -> None:
        super(AppServicePlanCollection, self).__init__(**kwargs)
        self.value = value
        self.next_link = None


class ArcConfiguration(Model):
    """ArcConfiguration.

    :param artifacts_storage_type: Possible values include: 'LocalNode',
     'NetworkFileSystem'
    :type artifacts_storage_type: str or
     ~azure.mgmt.web.v2021_02_01.models.StorageType
    :param artifact_storage_class_name:
    :type artifact_storage_class_name: str
    :param artifact_storage_mount_path:
    :type artifact_storage_mount_path: str
    :param artifact_storage_node_name:
    :type artifact_storage_node_name: str
    :param artifact_storage_access_mode:
    :type artifact_storage_access_mode: str
    :param front_end_service_configuration:
    :type front_end_service_configuration:
     ~azure.mgmt.web.v2021_02_01.models.FrontEndConfiguration
    :param kube_config:
    :type kube_config: str
    """

    _attribute_map = {
        'artifacts_storage_type': {'key': 'artifactsStorageType', 'type': 'StorageType'},
        'artifact_storage_class_name': {'key': 'artifactStorageClassName', 'type': 'str'},
        'artifact_storage_mount_path': {'key': 'artifactStorageMountPath', 'type': 'str'},
        'artifact_storage_node_name': {'key': 'artifactStorageNodeName', 'type': 'str'},
        'artifact_storage_access_mode': {'key': 'artifactStorageAccessMode', 'type': 'str'},
        'front_end_service_configuration': {'key': 'frontEndServiceConfiguration', 'type': 'FrontEndConfiguration'},
        'kube_config': {'key': 'kubeConfig', 'type': 'str'},
    }

    def __init__(self, *, artifacts_storage_type=None, artifact_storage_class_name: str=None, artifact_storage_mount_path: str=None, artifact_storage_node_name: str=None, artifact_storage_access_mode: str=None, front_end_service_configuration=None, kube_config: str=None, **kwargs) -> None:
        super(ArcConfiguration, self).__init__(**kwargs)
        self.artifacts_storage_type = artifacts_storage_type
        self.artifact_storage_class_name = artifact_storage_class_name
        self.artifact_storage_mount_path = artifact_storage_mount_path
        self.artifact_storage_node_name = artifact_storage_node_name
        self.artifact_storage_access_mode = artifact_storage_access_mode
        self.front_end_service_configuration = front_end_service_configuration
        self.kube_config = kube_config


class ArmIdWrapper(Model):
    """A wrapper for an ARM resource id.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar id:
    :vartype id: str
    """

    _validation = {
        'id': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
    }

    def __init__(self, **kwargs) -> None:
        super(ArmIdWrapper, self).__init__(**kwargs)
        self.id = None


class AutoHealActions(Model):
    """Actions which to take by the auto-heal module when a rule is triggered.

    :param action_type: Predefined action to be taken. Possible values
     include: 'Recycle', 'LogEvent', 'CustomAction'
    :type action_type: str or
     ~azure.mgmt.web.v2021_02_01.models.AutoHealActionType
    :param custom_action: Custom action to be taken.
    :type custom_action:
     ~azure.mgmt.web.v2021_02_01.models.AutoHealCustomAction
    :param min_process_execution_time: Minimum time the process must execute
     before taking the action
    :type min_process_execution_time: str
    """

    _attribute_map = {
        'action_type': {'key': 'actionType', 'type': 'AutoHealActionType'},
        'custom_action': {'key': 'customAction', 'type': 'AutoHealCustomAction'},
        'min_process_execution_time': {'key': 'minProcessExecutionTime', 'type': 'str'},
    }

    def __init__(self, *, action_type=None, custom_action=None, min_process_execution_time: str=None, **kwargs) -> None:
        super(AutoHealActions, self).__init__(**kwargs)
        self.action_type = action_type
        self.custom_action = custom_action
        self.min_process_execution_time = min_process_execution_time


class AutoHealCustomAction(Model):
    """Custom action to be executed
    when an auto heal rule is triggered.

    :param exe: Executable to be run.
    :type exe: str
    :param parameters: Parameters for the executable.
    :type parameters: str
    """

    _attribute_map = {
        'exe': {'key': 'exe', 'type': 'str'},
        'parameters': {'key': 'parameters', 'type': 'str'},
    }

    def __init__(self, *, exe: str=None, parameters: str=None, **kwargs) -> None:
        super(AutoHealCustomAction, self).__init__(**kwargs)
        self.exe = exe
        self.parameters = parameters


class AutoHealRules(Model):
    """Rules that can be defined for auto-heal.

    :param triggers: Conditions that describe when to execute the auto-heal
     actions.
    :type triggers: ~azure.mgmt.web.v2021_02_01.models.AutoHealTriggers
    :param actions: Actions to be executed when a rule is triggered.
    :type actions: ~azure.mgmt.web.v2021_02_01.models.AutoHealActions
    """

    _attribute_map = {
        'triggers': {'key': 'triggers', 'type': 'AutoHealTriggers'},
        'actions': {'key': 'actions', 'type': 'AutoHealActions'},
    }

    def __init__(self, *, triggers=None, actions=None, **kwargs) -> None:
        super(AutoHealRules, self).__init__(**kwargs)
        self.triggers = triggers
        self.actions = actions


class AutoHealTriggers(Model):
    """Triggers for auto-heal.

    :param requests: A rule based on total requests.
    :type requests: ~azure.mgmt.web.v2021_02_01.models.RequestsBasedTrigger
    :param private_bytes_in_kb: A rule based on private bytes.
    :type private_bytes_in_kb: int
    :param status_codes: A rule based on status codes.
    :type status_codes:
     list[~azure.mgmt.web.v2021_02_01.models.StatusCodesBasedTrigger]
    :param slow_requests: A rule based on request execution time.
    :type slow_requests:
     ~azure.mgmt.web.v2021_02_01.models.SlowRequestsBasedTrigger
    :param slow_requests_with_path: A rule based on multiple Slow Requests
     Rule with path
    :type slow_requests_with_path:
     list[~azure.mgmt.web.v2021_02_01.models.SlowRequestsBasedTrigger]
    :param status_codes_range: A rule based on status codes ranges.
    :type status_codes_range:
     list[~azure.mgmt.web.v2021_02_01.models.StatusCodesRangeBasedTrigger]
    """

    _attribute_map = {
        'requests': {'key': 'requests', 'type': 'RequestsBasedTrigger'},
        'private_bytes_in_kb': {'key': 'privateBytesInKB', 'type': 'int'},
        'status_codes': {'key': 'statusCodes', 'type': '[StatusCodesBasedTrigger]'},
        'slow_requests': {'key': 'slowRequests', 'type': 'SlowRequestsBasedTrigger'},
        'slow_requests_with_path': {'key': 'slowRequestsWithPath', 'type': '[SlowRequestsBasedTrigger]'},
        'status_codes_range': {'key': 'statusCodesRange', 'type': '[StatusCodesRangeBasedTrigger]'},
    }

    def __init__(self, *, requests=None, private_bytes_in_kb: int=None, status_codes=None, slow_requests=None, slow_requests_with_path=None, status_codes_range=None, **kwargs) -> None:
        super(AutoHealTriggers, self).__init__(**kwargs)
        self.requests = requests
        self.private_bytes_in_kb = private_bytes_in_kb
        self.status_codes = status_codes
        self.slow_requests = slow_requests
        self.slow_requests_with_path = slow_requests_with_path
        self.status_codes_range = status_codes_range


class AzureStorageInfoValue(Model):
    """Azure Files or Blob Storage access information value for dictionary
    storage.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param type: Type of storage. Possible values include: 'AzureFiles',
     'AzureBlob', 'FileShare'
    :type type: str or ~azure.mgmt.web.v2021_02_01.models.AzureStorageType
    :param account_name: Name of the storage account.
    :type account_name: str
    :param share_name: Name of the file share (container name, for Blob
     storage).
    :type share_name: str
    :param access_key: Access key for the storage account.
    :type access_key: str
    :param mount_path: Path to mount the storage within the site's runtime
     environment.
    :type mount_path: str
    :ivar state: State of the storage account. Possible values include: 'Ok',
     'InvalidCredentials', 'InvalidShare', 'NotValidated'
    :vartype state: str or
     ~azure.mgmt.web.v2021_02_01.models.AzureStorageState
    :param endpoint: Endpoint (IP or DNS name) of a customer-owned file server
    :type endpoint: str
    """

    _validation = {
        'state': {'readonly': True},
    }

    _attribute_map = {
        'type': {'key': 'type', 'type': 'AzureStorageType'},
        'account_name': {'key': 'accountName', 'type': 'str'},
        'share_name': {'key': 'shareName', 'type': 'str'},
        'access_key': {'key': 'accessKey', 'type': 'str'},
        'mount_path': {'key': 'mountPath', 'type': 'str'},
        'state': {'key': 'state', 'type': 'AzureStorageState'},
        'endpoint': {'key': 'endpoint', 'type': 'str'},
    }

    def __init__(self, *, type=None, account_name: str=None, share_name: str=None, access_key: str=None, mount_path: str=None, endpoint: str=None, **kwargs) -> None:
        super(AzureStorageInfoValue, self).__init__(**kwargs)
        self.type = type
        self.account_name = account_name
        self.share_name = share_name
        self.access_key = access_key
        self.mount_path = mount_path
        self.state = None
        self.endpoint = endpoint


class Capability(Model):
    """Describes the capabilities/features allowed for a specific SKU.

    :param name: Name of the SKU capability.
    :type name: str
    :param value: Value of the SKU capability.
    :type value: str
    :param reason: Reason of the SKU capability.
    :type reason: str
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'value': {'key': 'value', 'type': 'str'},
        'reason': {'key': 'reason', 'type': 'str'},
    }

    def __init__(self, *, name: str=None, value: str=None, reason: str=None, **kwargs) -> None:
        super(Capability, self).__init__(**kwargs)
        self.name = name
        self.value = value
        self.reason = reason


class CloningInfo(Model):
    """Information needed for cloning operation.

    All required parameters must be populated in order to send to Azure.

    :param correlation_id: Correlation ID of cloning operation. This ID ties
     multiple cloning operations
     together to use the same snapshot.
    :type correlation_id: str
    :param overwrite: <code>true</code> to overwrite destination app;
     otherwise, <code>false</code>.
    :type overwrite: bool
    :param clone_custom_host_names: <code>true</code> to clone custom
     hostnames from source app; otherwise, <code>false</code>.
    :type clone_custom_host_names: bool
    :param clone_source_control: <code>true</code> to clone source control
     from source app; otherwise, <code>false</code>.
    :type clone_source_control: bool
    :param source_web_app_id: Required. ARM resource ID of the source app. App
     resource ID is of the form
     /subscriptions/{subId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Web/sites/{siteName}
     for production slots and
     /subscriptions/{subId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Web/sites/{siteName}/slots/{slotName}
     for other slots.
    :type source_web_app_id: str
    :param source_web_app_location: Location of source app ex: West US or
     North Europe
    :type source_web_app_location: str
    :param hosting_environment: App Service Environment.
    :type hosting_environment: str
    :param app_settings_overrides: Application setting overrides for cloned
     app. If specified, these settings override the settings cloned
     from source app. Otherwise, application settings from source app are
     retained.
    :type app_settings_overrides: dict[str, str]
    :param configure_load_balancing: <code>true</code> to configure load
     balancing for source and destination app.
    :type configure_load_balancing: bool
    :param traffic_manager_profile_id: ARM resource ID of the Traffic Manager
     profile to use, if it exists. Traffic Manager resource ID is of the form
     /subscriptions/{subId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/trafficManagerProfiles/{profileName}.
    :type traffic_manager_profile_id: str
    :param traffic_manager_profile_name: Name of Traffic Manager profile to
     create. This is only needed if Traffic Manager profile does not already
     exist.
    :type traffic_manager_profile_name: str
    """

    _validation = {
        'source_web_app_id': {'required': True},
    }

    _attribute_map = {
        'correlation_id': {'key': 'correlationId', 'type': 'str'},
        'overwrite': {'key': 'overwrite', 'type': 'bool'},
        'clone_custom_host_names': {'key': 'cloneCustomHostNames', 'type': 'bool'},
        'clone_source_control': {'key': 'cloneSourceControl', 'type': 'bool'},
        'source_web_app_id': {'key': 'sourceWebAppId', 'type': 'str'},
        'source_web_app_location': {'key': 'sourceWebAppLocation', 'type': 'str'},
        'hosting_environment': {'key': 'hostingEnvironment', 'type': 'str'},
        'app_settings_overrides': {'key': 'appSettingsOverrides', 'type': '{str}'},
        'configure_load_balancing': {'key': 'configureLoadBalancing', 'type': 'bool'},
        'traffic_manager_profile_id': {'key': 'trafficManagerProfileId', 'type': 'str'},
        'traffic_manager_profile_name': {'key': 'trafficManagerProfileName', 'type': 'str'},
    }

    def __init__(self, *, source_web_app_id: str, correlation_id: str=None, overwrite: bool=None, clone_custom_host_names: bool=None, clone_source_control: bool=None, source_web_app_location: str=None, hosting_environment: str=None, app_settings_overrides=None, configure_load_balancing: bool=None, traffic_manager_profile_id: str=None, traffic_manager_profile_name: str=None, **kwargs) -> None:
        super(CloningInfo, self).__init__(**kwargs)
        self.correlation_id = correlation_id
        self.overwrite = overwrite
        self.clone_custom_host_names = clone_custom_host_names
        self.clone_source_control = clone_source_control
        self.source_web_app_id = source_web_app_id
        self.source_web_app_location = source_web_app_location
        self.hosting_environment = hosting_environment
        self.app_settings_overrides = app_settings_overrides
        self.configure_load_balancing = configure_load_balancing
        self.traffic_manager_profile_id = traffic_manager_profile_id
        self.traffic_manager_profile_name = traffic_manager_profile_name


class CloudError(Model):
    """CloudError.
    """

    _attribute_map = {
    }


class ConnStringInfo(Model):
    """Database connection string information.

    :param name: Name of connection string.
    :type name: str
    :param connection_string: Connection string value.
    :type connection_string: str
    :param type: Type of database. Possible values include: 'MySql',
     'SQLServer', 'SQLAzure', 'Custom', 'NotificationHub', 'ServiceBus',
     'EventHub', 'ApiHub', 'DocDb', 'RedisCache', 'PostgreSQL'
    :type type: str or ~azure.mgmt.web.v2021_02_01.models.ConnectionStringType
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'connection_string': {'key': 'connectionString', 'type': 'str'},
        'type': {'key': 'type', 'type': 'ConnectionStringType'},
    }

    def __init__(self, *, name: str=None, connection_string: str=None, type=None, **kwargs) -> None:
        super(ConnStringInfo, self).__init__(**kwargs)
        self.name = name
        self.connection_string = connection_string
        self.type = type


class CorsSettings(Model):
    """Cross-Origin Resource Sharing (CORS) settings for the app.

    :param allowed_origins: Gets or sets the list of origins that should be
     allowed to make cross-origin
     calls (for example: http://example.com:12345). Use "*" to allow all.
    :type allowed_origins: list[str]
    :param support_credentials: Gets or sets whether CORS requests with
     credentials are allowed. See
     https://developer.mozilla.org/en-US/docs/Web/HTTP/CORS#Requests_with_credentials
     for more details.
    :type support_credentials: bool
    """

    _attribute_map = {
        'allowed_origins': {'key': 'allowedOrigins', 'type': '[str]'},
        'support_credentials': {'key': 'supportCredentials', 'type': 'bool'},
    }

    def __init__(self, *, allowed_origins=None, support_credentials: bool=None, **kwargs) -> None:
        super(CorsSettings, self).__init__(**kwargs)
        self.allowed_origins = allowed_origins
        self.support_credentials = support_credentials


class CsmOperationCollection(Model):
    """Collection of Azure resource manager operation metadata.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    All required parameters must be populated in order to send to Azure.

    :param value: Required. Collection of resources.
    :type value:
     list[~azure.mgmt.web.v2021_02_01.models.CsmOperationDescription]
    :ivar next_link: Link to next page of resources.
    :vartype next_link: str
    """

    _validation = {
        'value': {'required': True},
        'next_link': {'readonly': True},
    }

    _attribute_map = {
        'value': {'key': 'value', 'type': '[CsmOperationDescription]'},
        'next_link': {'key': 'nextLink', 'type': 'str'},
    }

    def __init__(self, *, value, **kwargs) -> None:
        super(CsmOperationCollection, self).__init__(**kwargs)
        self.value = value
        self.next_link = None


class CsmOperationDescription(Model):
    """Description of an operation available for Microsoft.Web resource provider.

    :param name:
    :type name: str
    :param is_data_action:
    :type is_data_action: bool
    :param display:
    :type display: ~azure.mgmt.web.v2021_02_01.models.CsmOperationDisplay
    :param origin:
    :type origin: str
    :param properties:
    :type properties:
     ~azure.mgmt.web.v2021_02_01.models.CsmOperationDescriptionProperties
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'is_data_action': {'key': 'isDataAction', 'type': 'bool'},
        'display': {'key': 'display', 'type': 'CsmOperationDisplay'},
        'origin': {'key': 'origin', 'type': 'str'},
        'properties': {'key': 'properties', 'type': 'CsmOperationDescriptionProperties'},
    }

    def __init__(self, *, name: str=None, is_data_action: bool=None, display=None, origin: str=None, properties=None, **kwargs) -> None:
        super(CsmOperationDescription, self).__init__(**kwargs)
        self.name = name
        self.is_data_action = is_data_action
        self.display = display
        self.origin = origin
        self.properties = properties


class CsmOperationDescriptionProperties(Model):
    """Properties available for a Microsoft.Web resource provider operation.

    :param service_specification:
    :type service_specification:
     ~azure.mgmt.web.v2021_02_01.models.ServiceSpecification
    """

    _attribute_map = {
        'service_specification': {'key': 'serviceSpecification', 'type': 'ServiceSpecification'},
    }

    def __init__(self, *, service_specification=None, **kwargs) -> None:
        super(CsmOperationDescriptionProperties, self).__init__(**kwargs)
        self.service_specification = service_specification


class CsmOperationDisplay(Model):
    """Meta data about operation used for display in portal.

    :param provider:
    :type provider: str
    :param resource:
    :type resource: str
    :param operation:
    :type operation: str
    :param description:
    :type description: str
    """

    _attribute_map = {
        'provider': {'key': 'provider', 'type': 'str'},
        'resource': {'key': 'resource', 'type': 'str'},
        'operation': {'key': 'operation', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
    }

    def __init__(self, *, provider: str=None, resource: str=None, operation: str=None, description: str=None, **kwargs) -> None:
        super(CsmOperationDisplay, self).__init__(**kwargs)
        self.provider = provider
        self.resource = resource
        self.operation = operation
        self.description = description


class CsmUsageQuota(Model):
    """Usage of the quota resource.

    :param unit: Units of measurement for the quota resource.
    :type unit: str
    :param next_reset_time: Next reset time for the resource counter.
    :type next_reset_time: datetime
    :param current_value: The current value of the resource counter.
    :type current_value: long
    :param limit: The resource limit.
    :type limit: long
    :param name: Quota name.
    :type name: ~azure.mgmt.web.v2021_02_01.models.LocalizableString
    """

    _attribute_map = {
        'unit': {'key': 'unit', 'type': 'str'},
        'next_reset_time': {'key': 'nextResetTime', 'type': 'iso-8601'},
        'current_value': {'key': 'currentValue', 'type': 'long'},
        'limit': {'key': 'limit', 'type': 'long'},
        'name': {'key': 'name', 'type': 'LocalizableString'},
    }

    def __init__(self, *, unit: str=None, next_reset_time=None, current_value: int=None, limit: int=None, name=None, **kwargs) -> None:
        super(CsmUsageQuota, self).__init__(**kwargs)
        self.unit = unit
        self.next_reset_time = next_reset_time
        self.current_value = current_value
        self.limit = limit
        self.name = name


class CsmUsageQuotaCollection(Model):
    """Collection of CSM usage quotas.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    All required parameters must be populated in order to send to Azure.

    :param value: Required. Collection of resources.
    :type value: list[~azure.mgmt.web.v2021_02_01.models.CsmUsageQuota]
    :ivar next_link: Link to next page of resources.
    :vartype next_link: str
    """

    _validation = {
        'value': {'required': True},
        'next_link': {'readonly': True},
    }

    _attribute_map = {
        'value': {'key': 'value', 'type': '[CsmUsageQuota]'},
        'next_link': {'key': 'nextLink', 'type': 'str'},
    }

    def __init__(self, *, value, **kwargs) -> None:
        super(CsmUsageQuotaCollection, self).__init__(**kwargs)
        self.value = value
        self.next_link = None


class DataProviderMetadata(Model):
    """Additional configuration for a data providers.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param provider_name:
    :type provider_name: str
    :ivar property_bag: Settings for the data provider
    :vartype property_bag:
     list[~azure.mgmt.web.v2021_02_01.models.KeyValuePairStringObject]
    """

    _validation = {
        'property_bag': {'readonly': True},
    }

    _attribute_map = {
        'provider_name': {'key': 'providerName', 'type': 'str'},
        'property_bag': {'key': 'propertyBag', 'type': '[KeyValuePairStringObject]'},
    }

    def __init__(self, *, provider_name: str=None, **kwargs) -> None:
        super(DataProviderMetadata, self).__init__(**kwargs)
        self.provider_name = provider_name
        self.property_bag = None


class DataTableResponseColumn(Model):
    """Column definition.

    :param column_name: Name of the column
    :type column_name: str
    :param data_type: Data type which looks like 'String' or 'Int32'.
    :type data_type: str
    :param column_type: Column Type
    :type column_type: str
    """

    _attribute_map = {
        'column_name': {'key': 'columnName', 'type': 'str'},
        'data_type': {'key': 'dataType', 'type': 'str'},
        'column_type': {'key': 'columnType', 'type': 'str'},
    }

    def __init__(self, *, column_name: str=None, data_type: str=None, column_type: str=None, **kwargs) -> None:
        super(DataTableResponseColumn, self).__init__(**kwargs)
        self.column_name = column_name
        self.data_type = data_type
        self.column_type = column_type


class DataTableResponseObject(Model):
    """Data Table which defines columns and raw row values.

    :param table_name: Name of the table
    :type table_name: str
    :param columns: List of columns with data types
    :type columns:
     list[~azure.mgmt.web.v2021_02_01.models.DataTableResponseColumn]
    :param rows: Raw row values
    :type rows: list[str]
    """

    _attribute_map = {
        'table_name': {'key': 'tableName', 'type': 'str'},
        'columns': {'key': 'columns', 'type': '[DataTableResponseColumn]'},
        'rows': {'key': 'rows', 'type': '[str]'},
    }

    def __init__(self, *, table_name: str=None, columns=None, rows=None, **kwargs) -> None:
        super(DataTableResponseObject, self).__init__(**kwargs)
        self.table_name = table_name
        self.columns = columns
        self.rows = rows


class DefaultErrorResponse(Model):
    """App Service error response.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar error: Error model.
    :vartype error:
     ~azure.mgmt.web.v2021_02_01.models.DefaultErrorResponseError
    """

    _validation = {
        'error': {'readonly': True},
    }

    _attribute_map = {
        'error': {'key': 'error', 'type': 'DefaultErrorResponseError'},
    }

    def __init__(self, **kwargs) -> None:
        super(DefaultErrorResponse, self).__init__(**kwargs)
        self.error = None


class DefaultErrorResponseException(HttpOperationError):
    """Server responsed with exception of type: 'DefaultErrorResponse'.

    :param deserialize: A deserializer
    :param response: Server response to be deserialized.
    """

    def __init__(self, deserialize, response, *args):

        super(DefaultErrorResponseException, self).__init__(deserialize, response, 'DefaultErrorResponse', *args)


class DefaultErrorResponseError(Model):
    """Error model.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar code: Standardized string to programmatically identify the error.
    :vartype code: str
    :ivar message: Detailed error description and debugging information.
    :vartype message: str
    :ivar target: Detailed error description and debugging information.
    :vartype target: str
    :param details:
    :type details:
     list[~azure.mgmt.web.v2021_02_01.models.DefaultErrorResponseErrorDetailsItem]
    :ivar innererror: More information to debug error.
    :vartype innererror: str
    """

    _validation = {
        'code': {'readonly': True},
        'message': {'readonly': True},
        'target': {'readonly': True},
        'innererror': {'readonly': True},
    }

    _attribute_map = {
        'code': {'key': 'code', 'type': 'str'},
        'message': {'key': 'message', 'type': 'str'},
        'target': {'key': 'target', 'type': 'str'},
        'details': {'key': 'details', 'type': '[DefaultErrorResponseErrorDetailsItem]'},
        'innererror': {'key': 'innererror', 'type': 'str'},
    }

    def __init__(self, *, details=None, **kwargs) -> None:
        super(DefaultErrorResponseError, self).__init__(**kwargs)
        self.code = None
        self.message = None
        self.target = None
        self.details = details
        self.innererror = None


class DefaultErrorResponseErrorDetailsItem(Model):
    """Detailed errors.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar code: Standardized string to programmatically identify the error.
    :vartype code: str
    :ivar message: Detailed error description and debugging information.
    :vartype message: str
    :ivar target: Detailed error description and debugging information.
    :vartype target: str
    """

    _validation = {
        'code': {'readonly': True},
        'message': {'readonly': True},
        'target': {'readonly': True},
    }

    _attribute_map = {
        'code': {'key': 'code', 'type': 'str'},
        'message': {'key': 'message', 'type': 'str'},
        'target': {'key': 'target', 'type': 'str'},
    }

    def __init__(self, **kwargs) -> None:
        super(DefaultErrorResponseErrorDetailsItem, self).__init__(**kwargs)
        self.code = None
        self.message = None
        self.target = None


class ProxyOnlyResource(Model):
    """Azure proxy only resource. This resource is not tracked by Azure Resource
    Manager.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar id: Resource Id.
    :vartype id: str
    :ivar name: Resource Name.
    :vartype name: str
    :param kind: Kind of resource.
    :type kind: str
    :ivar type: Resource type.
    :vartype type: str
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'kind': {'key': 'kind', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
    }

    def __init__(self, *, kind: str=None, **kwargs) -> None:
        super(ProxyOnlyResource, self).__init__(**kwargs)
        self.id = None
        self.name = None
        self.kind = kind
        self.type = None


class DeletedSite(ProxyOnlyResource):
    """A deleted app.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar id: Resource Id.
    :vartype id: str
    :ivar name: Resource Name.
    :vartype name: str
    :param kind: Kind of resource.
    :type kind: str
    :ivar type: Resource type.
    :vartype type: str
    :ivar deleted_site_id: Numeric id for the deleted site
    :vartype deleted_site_id: int
    :ivar deleted_timestamp: Time in UTC when the app was deleted.
    :vartype deleted_timestamp: str
    :ivar subscription: Subscription containing the deleted site
    :vartype subscription: str
    :ivar resource_group: ResourceGroup that contained the deleted site
    :vartype resource_group: str
    :ivar deleted_site_name: Name of the deleted site
    :vartype deleted_site_name: str
    :ivar slot: Slot of the deleted site
    :vartype slot: str
    :ivar deleted_site_kind: Kind of site that was deleted
    :vartype deleted_site_kind: str
    :ivar geo_region_name: Geo Region of the deleted site
    :vartype geo_region_name: str
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
        'deleted_site_id': {'readonly': True},
        'deleted_timestamp': {'readonly': True},
        'subscription': {'readonly': True},
        'resource_group': {'readonly': True},
        'deleted_site_name': {'readonly': True},
        'slot': {'readonly': True},
        'deleted_site_kind': {'readonly': True},
        'geo_region_name': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'kind': {'key': 'kind', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'deleted_site_id': {'key': 'properties.deletedSiteId', 'type': 'int'},
        'deleted_timestamp': {'key': 'properties.deletedTimestamp', 'type': 'str'},
        'subscription': {'key': 'properties.subscription', 'type': 'str'},
        'resource_group': {'key': 'properties.resourceGroup', 'type': 'str'},
        'deleted_site_name': {'key': 'properties.deletedSiteName', 'type': 'str'},
        'slot': {'key': 'properties.slot', 'type': 'str'},
        'deleted_site_kind': {'key': 'properties.kind', 'type': 'str'},
        'geo_region_name': {'key': 'properties.geoRegionName', 'type': 'str'},
    }

    def __init__(self, *, kind: str=None, **kwargs) -> None:
        super(DeletedSite, self).__init__(kind=kind, **kwargs)
        self.deleted_site_id = None
        self.deleted_timestamp = None
        self.subscription = None
        self.resource_group = None
        self.deleted_site_name = None
        self.slot = None
        self.deleted_site_kind = None
        self.geo_region_name = None


class DetectorInfo(Model):
    """Definition of Detector.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar id: Id of detector
    :vartype id: str
    :ivar name: Name of detector
    :vartype name: str
    :ivar description: Short description of the detector and its purpose.
    :vartype description: str
    :ivar author: Author of the detector.
    :vartype author: str
    :ivar category: Problem category. This serves for organizing group for
     detectors.
    :vartype category: str
    :ivar support_topic_list: List of Support Topics for which this detector
     is enabled.
    :vartype support_topic_list:
     list[~azure.mgmt.web.v2021_02_01.models.SupportTopic]
    :ivar analysis_type: Analysis Types for which this detector should apply
     to.
    :vartype analysis_type: list[str]
    :ivar type: Whether this detector is an Analysis Detector or not. Possible
     values include: 'Detector', 'Analysis', 'CategoryOverview'
    :vartype type: str or ~azure.mgmt.web.v2021_02_01.models.DetectorType
    :ivar score: Defines score of a detector to power ML based matching.
    :vartype score: float
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'description': {'readonly': True},
        'author': {'readonly': True},
        'category': {'readonly': True},
        'support_topic_list': {'readonly': True},
        'analysis_type': {'readonly': True},
        'type': {'readonly': True},
        'score': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'author': {'key': 'author', 'type': 'str'},
        'category': {'key': 'category', 'type': 'str'},
        'support_topic_list': {'key': 'supportTopicList', 'type': '[SupportTopic]'},
        'analysis_type': {'key': 'analysisType', 'type': '[str]'},
        'type': {'key': 'type', 'type': 'DetectorType'},
        'score': {'key': 'score', 'type': 'float'},
    }

    def __init__(self, **kwargs) -> None:
        super(DetectorInfo, self).__init__(**kwargs)
        self.id = None
        self.name = None
        self.description = None
        self.author = None
        self.category = None
        self.support_topic_list = None
        self.analysis_type = None
        self.type = None
        self.score = None


class DetectorResponse(ProxyOnlyResource):
    """Class representing Response from Detector.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar id: Resource Id.
    :vartype id: str
    :ivar name: Resource Name.
    :vartype name: str
    :param kind: Kind of resource.
    :type kind: str
    :ivar type: Resource type.
    :vartype type: str
    :param metadata: metadata for the detector
    :type metadata: ~azure.mgmt.web.v2021_02_01.models.DetectorInfo
    :param dataset: Data Set
    :type dataset: list[~azure.mgmt.web.v2021_02_01.models.DiagnosticData]
    :param status: Indicates status of the most severe insight.
    :type status: ~azure.mgmt.web.v2021_02_01.models.Status
    :param data_providers_metadata: Additional configuration for different
     data providers to be used by the UI
    :type data_providers_metadata:
     list[~azure.mgmt.web.v2021_02_01.models.DataProviderMetadata]
    :param suggested_utterances: Suggested utterances where the detector can
     be applicable.
    :type suggested_utterances:
     ~azure.mgmt.web.v2021_02_01.models.QueryUtterancesResults
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'kind': {'key': 'kind', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'metadata': {'key': 'properties.metadata', 'type': 'DetectorInfo'},
        'dataset': {'key': 'properties.dataset', 'type': '[DiagnosticData]'},
        'status': {'key': 'properties.status', 'type': 'Status'},
        'data_providers_metadata': {'key': 'properties.dataProvidersMetadata', 'type': '[DataProviderMetadata]'},
        'suggested_utterances': {'key': 'properties.suggestedUtterances', 'type': 'QueryUtterancesResults'},
    }

    def __init__(self, *, kind: str=None, metadata=None, dataset=None, status=None, data_providers_metadata=None, suggested_utterances=None, **kwargs) -> None:
        super(DetectorResponse, self).__init__(kind=kind, **kwargs)
        self.metadata = metadata
        self.dataset = dataset
        self.status = status
        self.data_providers_metadata = data_providers_metadata
        self.suggested_utterances = suggested_utterances


class DetectorResponseCollection(Model):
    """Collection of detector responses.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    All required parameters must be populated in order to send to Azure.

    :param value: Required. Collection of resources.
    :type value: list[~azure.mgmt.web.v2021_02_01.models.DetectorResponse]
    :ivar next_link: Link to next page of resources.
    :vartype next_link: str
    """

    _validation = {
        'value': {'required': True},
        'next_link': {'readonly': True},
    }

    _attribute_map = {
        'value': {'key': 'value', 'type': '[DetectorResponse]'},
        'next_link': {'key': 'nextLink', 'type': 'str'},
    }

    def __init__(self, *, value, **kwargs) -> None:
        super(DetectorResponseCollection, self).__init__(**kwargs)
        self.value = value
        self.next_link = None


class DiagnosticData(Model):
    """Set of data with rendering instructions.

    :param table: Data in table form
    :type table: ~azure.mgmt.web.v2021_02_01.models.DataTableResponseObject
    :param rendering_properties: Properties that describe how the table should
     be rendered
    :type rendering_properties: ~azure.mgmt.web.v2021_02_01.models.Rendering
    """

    _attribute_map = {
        'table': {'key': 'table', 'type': 'DataTableResponseObject'},
        'rendering_properties': {'key': 'renderingProperties', 'type': 'Rendering'},
    }

    def __init__(self, *, table=None, rendering_properties=None, **kwargs) -> None:
        super(DiagnosticData, self).__init__(**kwargs)
        self.table = table
        self.rendering_properties = rendering_properties


class Dimension(Model):
    """Dimension of a resource metric. For e.g. instance specific HTTP requests
    for a web app,
    where instance name is dimension of the metric HTTP request.

    :param name:
    :type name: str
    :param display_name:
    :type display_name: str
    :param internal_name:
    :type internal_name: str
    :param to_be_exported_for_shoebox:
    :type to_be_exported_for_shoebox: bool
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'display_name': {'key': 'displayName', 'type': 'str'},
        'internal_name': {'key': 'internalName', 'type': 'str'},
        'to_be_exported_for_shoebox': {'key': 'toBeExportedForShoebox', 'type': 'bool'},
    }

    def __init__(self, *, name: str=None, display_name: str=None, internal_name: str=None, to_be_exported_for_shoebox: bool=None, **kwargs) -> None:
        super(Dimension, self).__init__(**kwargs)
        self.name = name
        self.display_name = display_name
        self.internal_name = internal_name
        self.to_be_exported_for_shoebox = to_be_exported_for_shoebox


class ErrorEntity(Model):
    """Body of the error response returned from the API.

    :param extended_code: Type of error.
    :type extended_code: str
    :param message_template: Message template.
    :type message_template: str
    :param parameters: Parameters for the template.
    :type parameters: list[str]
    :param inner_errors: Inner errors.
    :type inner_errors: list[~azure.mgmt.web.v2021_02_01.models.ErrorEntity]
    :param details: Error Details.
    :type details: list[~azure.mgmt.web.v2021_02_01.models.ErrorEntity]
    :param target: The error target.
    :type target: str
    :param code: Basic error code.
    :type code: str
    :param message: Any details of the error.
    :type message: str
    """

    _attribute_map = {
        'extended_code': {'key': 'extendedCode', 'type': 'str'},
        'message_template': {'key': 'messageTemplate', 'type': 'str'},
        'parameters': {'key': 'parameters', 'type': '[str]'},
        'inner_errors': {'key': 'innerErrors', 'type': '[ErrorEntity]'},
        'details': {'key': 'details', 'type': '[ErrorEntity]'},
        'target': {'key': 'target', 'type': 'str'},
        'code': {'key': 'code', 'type': 'str'},
        'message': {'key': 'message', 'type': 'str'},
    }

    def __init__(self, *, extended_code: str=None, message_template: str=None, parameters=None, inner_errors=None, details=None, target: str=None, code: str=None, message: str=None, **kwargs) -> None:
        super(ErrorEntity, self).__init__(**kwargs)
        self.extended_code = extended_code
        self.message_template = message_template
        self.parameters = parameters
        self.inner_errors = inner_errors
        self.details = details
        self.target = target
        self.code = code
        self.message = message


class Experiments(Model):
    """Routing rules in production experiments.

    :param ramp_up_rules: List of ramp-up rules.
    :type ramp_up_rules: list[~azure.mgmt.web.v2021_02_01.models.RampUpRule]
    """

    _attribute_map = {
        'ramp_up_rules': {'key': 'rampUpRules', 'type': '[RampUpRule]'},
    }

    def __init__(self, *, ramp_up_rules=None, **kwargs) -> None:
        super(Experiments, self).__init__(**kwargs)
        self.ramp_up_rules = ramp_up_rules


class ExtendedLocation(Model):
    """Extended Location.

    :param name: Name of extended location.
    :type name: str
    :param type: Type of extended location.
    :type type: str
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
    }

    def __init__(self, *, name: str=None, type: str=None, **kwargs) -> None:
        super(ExtendedLocation, self).__init__(**kwargs)
        self.name = name
        self.type = type


class FrontEndConfiguration(Model):
    """FrontEndConfiguration.

    :param kind: Possible values include: 'NodePort', 'LoadBalancer'
    :type kind: str or ~azure.mgmt.web.v2021_02_01.models.FrontEndServiceType
    """

    _attribute_map = {
        'kind': {'key': 'kind', 'type': 'FrontEndServiceType'},
    }

    def __init__(self, *, kind=None, **kwargs) -> None:
        super(FrontEndConfiguration, self).__init__(**kwargs)
        self.kind = kind


class GitHubActionWorkflowRequest(Model):
    """The GitHub action workflow request.

    :param app_type: The app type. This would be either 'WebApp' or
     'FunctionApp'.
    :type app_type: str
    :param publish_type: The publish type. This would either 'code' or
     'container'.
    :type publish_type: str
    :param os: The os. This would be either 'windows' or 'linux'.
    :type os: str
    :param variables: The variables. These are name/value pairs which replace
     the placeholders in the workflow file templates.
    :type variables: dict[str, str]
    :param runtime_stack: The runtime stack. This would be one of 'dotnet',
     'java', 'python', etc. if the PublishType is set to code.
    :type runtime_stack: str
    :param workflow_api_version: The version of the fusion workflow API to
     call.
    :type workflow_api_version: str
    :param use_canary_fusion_server: The flag indicting whether to call the
     canary fusion server.
    :type use_canary_fusion_server: bool
    """

    _attribute_map = {
        'app_type': {'key': 'appType', 'type': 'str'},
        'publish_type': {'key': 'publishType', 'type': 'str'},
        'os': {'key': 'os', 'type': 'str'},
        'variables': {'key': 'variables', 'type': '{str}'},
        'runtime_stack': {'key': 'runtimeStack', 'type': 'str'},
        'workflow_api_version': {'key': 'workflowApiVersion', 'type': 'str'},
        'use_canary_fusion_server': {'key': 'useCanaryFusionServer', 'type': 'bool'},
    }

    def __init__(self, *, app_type: str=None, publish_type: str=None, os: str=None, variables=None, runtime_stack: str=None, workflow_api_version: str=None, use_canary_fusion_server: bool=None, **kwargs) -> None:
        super(GitHubActionWorkflowRequest, self).__init__(**kwargs)
        self.app_type = app_type
        self.publish_type = publish_type
        self.os = os
        self.variables = variables
        self.runtime_stack = runtime_stack
        self.workflow_api_version = workflow_api_version
        self.use_canary_fusion_server = use_canary_fusion_server


class HandlerMapping(Model):
    """The IIS handler mappings used to define which handler processes HTTP
    requests with certain extension.
    For example, it is used to configure php-cgi.exe process to handle all HTTP
    requests with *.php extension.

    :param extension: Requests with this extension will be handled using the
     specified FastCGI application.
    :type extension: str
    :param script_processor: The absolute path to the FastCGI application.
    :type script_processor: str
    :param arguments: Command-line arguments to be passed to the script
     processor.
    :type arguments: str
    """

    _attribute_map = {
        'extension': {'key': 'extension', 'type': 'str'},
        'script_processor': {'key': 'scriptProcessor', 'type': 'str'},
        'arguments': {'key': 'arguments', 'type': 'str'},
    }

    def __init__(self, *, extension: str=None, script_processor: str=None, arguments: str=None, **kwargs) -> None:
        super(HandlerMapping, self).__init__(**kwargs)
        self.extension = extension
        self.script_processor = script_processor
        self.arguments = arguments


class HostingEnvironmentProfile(Model):
    """Specification for an App Service Environment to use for this resource.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param id: Resource ID of the App Service Environment.
    :type id: str
    :ivar name: Name of the App Service Environment.
    :vartype name: str
    :ivar type: Resource type of the App Service Environment.
    :vartype type: str
    """

    _validation = {
        'name': {'readonly': True},
        'type': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
    }

    def __init__(self, *, id: str=None, **kwargs) -> None:
        super(HostingEnvironmentProfile, self).__init__(**kwargs)
        self.id = id
        self.name = None
        self.type = None


class HostNameSslState(Model):
    """SSL-enabled hostname.

    :param name: Hostname.
    :type name: str
    :param ssl_state: SSL type. Possible values include: 'Disabled',
     'SniEnabled', 'IpBasedEnabled'
    :type ssl_state: str or ~azure.mgmt.web.v2021_02_01.models.SslState
    :param virtual_ip: Virtual IP address assigned to the hostname if IP based
     SSL is enabled.
    :type virtual_ip: str
    :param thumbprint: SSL certificate thumbprint.
    :type thumbprint: str
    :param to_update: Set to <code>true</code> to update existing hostname.
    :type to_update: bool
    :param host_type: Indicates whether the hostname is a standard or
     repository hostname. Possible values include: 'Standard', 'Repository'
    :type host_type: str or ~azure.mgmt.web.v2021_02_01.models.HostType
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'ssl_state': {'key': 'sslState', 'type': 'SslState'},
        'virtual_ip': {'key': 'virtualIP', 'type': 'str'},
        'thumbprint': {'key': 'thumbprint', 'type': 'str'},
        'to_update': {'key': 'toUpdate', 'type': 'bool'},
        'host_type': {'key': 'hostType', 'type': 'HostType'},
    }

    def __init__(self, *, name: str=None, ssl_state=None, virtual_ip: str=None, thumbprint: str=None, to_update: bool=None, host_type=None, **kwargs) -> None:
        super(HostNameSslState, self).__init__(**kwargs)
        self.name = name
        self.ssl_state = ssl_state
        self.virtual_ip = virtual_ip
        self.thumbprint = thumbprint
        self.to_update = to_update
        self.host_type = host_type


class HybridConnection(ProxyOnlyResource):
    """Hybrid Connection contract. This is used to configure a Hybrid Connection.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar id: Resource Id.
    :vartype id: str
    :ivar name: Resource Name.
    :vartype name: str
    :param kind: Kind of resource.
    :type kind: str
    :ivar type: Resource type.
    :vartype type: str
    :param service_bus_namespace: The name of the Service Bus namespace.
    :type service_bus_namespace: str
    :param relay_name: The name of the Service Bus relay.
    :type relay_name: str
    :param relay_arm_uri: The ARM URI to the Service Bus relay.
    :type relay_arm_uri: str
    :param hostname: The hostname of the endpoint.
    :type hostname: str
    :param port: The port of the endpoint.
    :type port: int
    :param send_key_name: The name of the Service Bus key which has Send
     permissions. This is used to authenticate to Service Bus.
    :type send_key_name: str
    :param send_key_value: The value of the Service Bus key. This is used to
     authenticate to Service Bus. In ARM this key will not be returned
     normally, use the POST /listKeys API instead.
    :type send_key_value: str
    :param service_bus_suffix: The suffix for the service bus endpoint. By
     default this is .servicebus.windows.net
    :type service_bus_suffix: str
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'kind': {'key': 'kind', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'service_bus_namespace': {'key': 'properties.serviceBusNamespace', 'type': 'str'},
        'relay_name': {'key': 'properties.relayName', 'type': 'str'},
        'relay_arm_uri': {'key': 'properties.relayArmUri', 'type': 'str'},
        'hostname': {'key': 'properties.hostname', 'type': 'str'},
        'port': {'key': 'properties.port', 'type': 'int'},
        'send_key_name': {'key': 'properties.sendKeyName', 'type': 'str'},
        'send_key_value': {'key': 'properties.sendKeyValue', 'type': 'str'},
        'service_bus_suffix': {'key': 'properties.serviceBusSuffix', 'type': 'str'},
    }

    def __init__(self, *, kind: str=None, service_bus_namespace: str=None, relay_name: str=None, relay_arm_uri: str=None, hostname: str=None, port: int=None, send_key_name: str=None, send_key_value: str=None, service_bus_suffix: str=None, **kwargs) -> None:
        super(HybridConnection, self).__init__(kind=kind, **kwargs)
        self.service_bus_namespace = service_bus_namespace
        self.relay_name = relay_name
        self.relay_arm_uri = relay_arm_uri
        self.hostname = hostname
        self.port = port
        self.send_key_name = send_key_name
        self.send_key_value = send_key_value
        self.service_bus_suffix = service_bus_suffix


class Identifier(ProxyOnlyResource):
    """A domain specific resource identifier.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar id: Resource Id.
    :vartype id: str
    :ivar name: Resource Name.
    :vartype name: str
    :param kind: Kind of resource.
    :type kind: str
    :ivar type: Resource type.
    :vartype type: str
    :param value: String representation of the identity.
    :type value: str
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'kind': {'key': 'kind', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'value': {'key': 'properties.id', 'type': 'str'},
    }

    def __init__(self, *, kind: str=None, value: str=None, **kwargs) -> None:
        super(Identifier, self).__init__(kind=kind, **kwargs)
        self.value = value


class IdentifierCollection(Model):
    """Collection of identifiers.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    All required parameters must be populated in order to send to Azure.

    :param value: Required. Collection of resources.
    :type value: list[~azure.mgmt.web.v2021_02_01.models.Identifier]
    :ivar next_link: Link to next page of resources.
    :vartype next_link: str
    """

    _validation = {
        'value': {'required': True},
        'next_link': {'readonly': True},
    }

    _attribute_map = {
        'value': {'key': 'value', 'type': '[Identifier]'},
        'next_link': {'key': 'nextLink', 'type': 'str'},
    }

    def __init__(self, *, value, **kwargs) -> None:
        super(IdentifierCollection, self).__init__(**kwargs)
        self.value = value
        self.next_link = None


class IpSecurityRestriction(Model):
    """IP security restriction on an app.

    :param ip_address: IP address the security restriction is valid for.
     It can be in form of pure ipv4 address (required SubnetMask property) or
     CIDR notation such as ipv4/mask (leading bit match). For CIDR,
     SubnetMask property must not be specified.
    :type ip_address: str
    :param subnet_mask: Subnet mask for the range of IP addresses the
     restriction is valid for.
    :type subnet_mask: str
    :param vnet_subnet_resource_id: Virtual network resource id
    :type vnet_subnet_resource_id: str
    :param vnet_traffic_tag: (internal) Vnet traffic tag
    :type vnet_traffic_tag: int
    :param subnet_traffic_tag: (internal) Subnet traffic tag
    :type subnet_traffic_tag: int
    :param action: Allow or Deny access for this IP range.
    :type action: str
    :param tag: Defines what this IP filter will be used for. This is to
     support IP filtering on proxies. Possible values include: 'Default',
     'XffProxy', 'ServiceTag'
    :type tag: str or ~azure.mgmt.web.v2021_02_01.models.IpFilterTag
    :param priority: Priority of IP restriction rule.
    :type priority: int
    :param name: IP restriction rule name.
    :type name: str
    :param description: IP restriction rule description.
    :type description: str
    :param headers: IP restriction rule headers.
     X-Forwarded-Host
     (https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Forwarded-Host#Examples).
     The matching logic is ..
     - If the property is null or empty (default), all hosts(or lack of) are
     allowed.
     - A value is compared using ordinal-ignore-case (excluding port number).
     - Subdomain wildcards are permitted but don't match the root domain. For
     example, *.contoso.com matches the subdomain foo.contoso.com
     but not the root domain contoso.com or multi-level foo.bar.contoso.com
     - Unicode host names are allowed but are converted to Punycode for
     matching.
     X-Forwarded-For
     (https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Forwarded-For#Examples).
     The matching logic is ..
     - If the property is null or empty (default), any forwarded-for chains (or
     lack of) are allowed.
     - If any address (excluding port number) in the chain (comma separated)
     matches the CIDR defined by the property.
     X-Azure-FDID and X-FD-HealthProbe.
     The matching logic is exact match.
    :type headers: dict[str, list[str]]
    """

    _attribute_map = {
        'ip_address': {'key': 'ipAddress', 'type': 'str'},
        'subnet_mask': {'key': 'subnetMask', 'type': 'str'},
        'vnet_subnet_resource_id': {'key': 'vnetSubnetResourceId', 'type': 'str'},
        'vnet_traffic_tag': {'key': 'vnetTrafficTag', 'type': 'int'},
        'subnet_traffic_tag': {'key': 'subnetTrafficTag', 'type': 'int'},
        'action': {'key': 'action', 'type': 'str'},
        'tag': {'key': 'tag', 'type': 'str'},
        'priority': {'key': 'priority', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'headers': {'key': 'headers', 'type': '{[str]}'},
    }

    def __init__(self, *, ip_address: str=None, subnet_mask: str=None, vnet_subnet_resource_id: str=None, vnet_traffic_tag: int=None, subnet_traffic_tag: int=None, action: str=None, tag=None, priority: int=None, name: str=None, description: str=None, headers=None, **kwargs) -> None:
        super(IpSecurityRestriction, self).__init__(**kwargs)
        self.ip_address = ip_address
        self.subnet_mask = subnet_mask
        self.vnet_subnet_resource_id = vnet_subnet_resource_id
        self.vnet_traffic_tag = vnet_traffic_tag
        self.subnet_traffic_tag = subnet_traffic_tag
        self.action = action
        self.tag = tag
        self.priority = priority
        self.name = name
        self.description = description
        self.headers = headers


class KeyValuePairStringObject(Model):
    """KeyValuePairStringObject.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar key:
    :vartype key: str
    :ivar value:
    :vartype value: object
    """

    _validation = {
        'key': {'readonly': True},
        'value': {'readonly': True},
    }

    _attribute_map = {
        'key': {'key': 'key', 'type': 'str'},
        'value': {'key': 'value', 'type': 'object'},
    }

    def __init__(self, **kwargs) -> None:
        super(KeyValuePairStringObject, self).__init__(**kwargs)
        self.key = None
        self.value = None


class KubeEnvironment(Resource):
    """A Kubernetes cluster specialized for web workloads by Azure App Service.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    All required parameters must be populated in order to send to Azure.

    :ivar id: Resource Id.
    :vartype id: str
    :ivar name: Resource Name.
    :vartype name: str
    :param kind: Kind of resource.
    :type kind: str
    :param location: Required. Resource Location.
    :type location: str
    :ivar type: Resource type.
    :vartype type: str
    :param tags: Resource tags.
    :type tags: dict[str, str]
    :param kube_environment_type: Type of the Kubernetes Environment.
     Only Set for WorkerApps as Managed
    :type kube_environment_type: str
    :ivar provisioning_state: Provisioning state of the Kubernetes
     Environment. Possible values include: 'Succeeded', 'Failed', 'Canceled',
     'Waiting', 'InitializationInProgress', 'InfrastructureSetupInProgress',
     'InfrastructureSetupComplete', 'ScheduledForDelete', 'UpgradeRequested',
     'UpgradeFailed', 'ClusterProvisioningInProgress',
     'ClusterProvisioningCompleted', 'ReadyForAllocation',
     'SuccessfullyConfigured'
    :vartype provisioning_state: str or
     ~azure.mgmt.web.v2021_02_01.models.KubeEnvironmentProvisioningState
    :ivar deployment_errors: Any errors that occurred during deployment or
     deployment validation
    :vartype deployment_errors: str
    :param internal_load_balancer_enabled: Only visible within Vnet/Subnet
    :type internal_load_balancer_enabled: bool
    :ivar default_domain: Default Domain Name for the cluster
    :vartype default_domain: str
    :param static_ip: Static IP of the KubeEnvironment
    :type static_ip: str
    :param arc_configuration: Cluster configuration which determines the ARC
     cluster
     components types. Eg: Choosing between BuildService kind,
     FrontEnd Service ArtifactsStorageType etc.
    :type arc_configuration:
     ~azure.mgmt.web.v2021_02_01.models.ArcConfiguration
    :param app_logs_configuration: Cluster configuration which enables the log
     daemon to export
     app logs to a destination. Currently only "log-analytics" is
     supported
    :type app_logs_configuration:
     ~azure.mgmt.web.v2021_02_01.models.AppLogsConfiguration
    :param worker_apps_configuration: Cluster configuration which enables
     users to create Worker Apps
     enabled dedicated Kube Environments
    :type worker_apps_configuration:
     ~azure.mgmt.web.v2021_02_01.models.WorkerAppsConfiguration
    :param aks_resource_id:
    :type aks_resource_id: str
    :param extended_location:
    :type extended_location:
     ~azure.mgmt.web.v2021_02_01.models.ExtendedLocation
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'location': {'required': True},
        'type': {'readonly': True},
        'provisioning_state': {'readonly': True},
        'deployment_errors': {'readonly': True},
        'default_domain': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'kind': {'key': 'kind', 'type': 'str'},
        'location': {'key': 'location', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'tags': {'key': 'tags', 'type': '{str}'},
        'kube_environment_type': {'key': 'properties.type', 'type': 'str'},
        'provisioning_state': {'key': 'properties.provisioningState', 'type': 'KubeEnvironmentProvisioningState'},
        'deployment_errors': {'key': 'properties.deploymentErrors', 'type': 'str'},
        'internal_load_balancer_enabled': {'key': 'properties.internalLoadBalancerEnabled', 'type': 'bool'},
        'default_domain': {'key': 'properties.defaultDomain', 'type': 'str'},
        'static_ip': {'key': 'properties.staticIp', 'type': 'str'},
        'arc_configuration': {'key': 'properties.arcConfiguration', 'type': 'ArcConfiguration'},
        'app_logs_configuration': {'key': 'properties.appLogsConfiguration', 'type': 'AppLogsConfiguration'},
        'worker_apps_configuration': {'key': 'properties.workerAppsConfiguration', 'type': 'WorkerAppsConfiguration'},
        'aks_resource_id': {'key': 'properties.aksResourceID', 'type': 'str'},
        'extended_location': {'key': 'extendedLocation', 'type': 'ExtendedLocation'},
    }

    def __init__(self, *, location: str, kind: str=None, tags=None, kube_environment_type: str=None, internal_load_balancer_enabled: bool=None, static_ip: str=None, arc_configuration=None, app_logs_configuration=None, worker_apps_configuration=None, aks_resource_id: str=None, extended_location=None, **kwargs) -> None:
        super(KubeEnvironment, self).__init__(kind=kind, location=location, tags=tags, **kwargs)
        self.kube_environment_type = kube_environment_type
        self.provisioning_state = None
        self.deployment_errors = None
        self.internal_load_balancer_enabled = internal_load_balancer_enabled
        self.default_domain = None
        self.static_ip = static_ip
        self.arc_configuration = arc_configuration
        self.app_logs_configuration = app_logs_configuration
        self.worker_apps_configuration = worker_apps_configuration
        self.aks_resource_id = aks_resource_id
        self.extended_location = extended_location


class KubeEnvironmentProfile(Model):
    """Specification for a Kubernetes Environment to use for this resource.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param id: Resource ID of the Kubernetes Environment.
    :type id: str
    :ivar name: Name of the Kubernetes Environment.
    :vartype name: str
    :ivar type: Resource type of the Kubernetes Environment.
    :vartype type: str
    """

    _validation = {
        'name': {'readonly': True},
        'type': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
    }

    def __init__(self, *, id: str=None, **kwargs) -> None:
        super(KubeEnvironmentProfile, self).__init__(**kwargs)
        self.id = id
        self.name = None
        self.type = None


class LocalizableString(Model):
    """Localizable string object containing the name and a localized value.

    :param value: Non-localized name.
    :type value: str
    :param localized_value: Localized name.
    :type localized_value: str
    """

    _attribute_map = {
        'value': {'key': 'value', 'type': 'str'},
        'localized_value': {'key': 'localizedValue', 'type': 'str'},
    }

    def __init__(self, *, value: str=None, localized_value: str=None, **kwargs) -> None:
        super(LocalizableString, self).__init__(**kwargs)
        self.value = value
        self.localized_value = localized_value


class LogAnalyticsConfiguration(Model):
    """LogAnalyticsConfiguration.

    :param customer_id:
    :type customer_id: str
    :param shared_key:
    :type shared_key: str
    """

    _attribute_map = {
        'customer_id': {'key': 'customerId', 'type': 'str'},
        'shared_key': {'key': 'sharedKey', 'type': 'str'},
    }

    def __init__(self, *, customer_id: str=None, shared_key: str=None, **kwargs) -> None:
        super(LogAnalyticsConfiguration, self).__init__(**kwargs)
        self.customer_id = customer_id
        self.shared_key = shared_key


class LogSpecification(Model):
    """Log Definition of a single resource metric.

    :param name:
    :type name: str
    :param display_name:
    :type display_name: str
    :param blob_duration:
    :type blob_duration: str
    :param log_filter_pattern:
    :type log_filter_pattern: str
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'display_name': {'key': 'displayName', 'type': 'str'},
        'blob_duration': {'key': 'blobDuration', 'type': 'str'},
        'log_filter_pattern': {'key': 'logFilterPattern', 'type': 'str'},
    }

    def __init__(self, *, name: str=None, display_name: str=None, blob_duration: str=None, log_filter_pattern: str=None, **kwargs) -> None:
        super(LogSpecification, self).__init__(**kwargs)
        self.name = name
        self.display_name = display_name
        self.blob_duration = blob_duration
        self.log_filter_pattern = log_filter_pattern


class ManagedServiceIdentity(Model):
    """Managed service identity.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param type: Type of managed service identity. Possible values include:
     'SystemAssigned', 'UserAssigned', 'SystemAssigned, UserAssigned', 'None'
    :type type: str or
     ~azure.mgmt.web.v2021_02_01.models.ManagedServiceIdentityType
    :ivar tenant_id: Tenant of managed service identity.
    :vartype tenant_id: str
    :ivar principal_id: Principal Id of managed service identity.
    :vartype principal_id: str
    :param user_assigned_identities: The list of user assigned identities
     associated with the resource. The user identity dictionary key references
     will be ARM resource ids in the form:
     '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ManagedIdentity/userAssignedIdentities/{identityName}
    :type user_assigned_identities: dict[str,
     ~azure.mgmt.web.v2021_02_01.models.UserAssignedIdentity]
    """

    _validation = {
        'tenant_id': {'readonly': True},
        'principal_id': {'readonly': True},
    }

    _attribute_map = {
        'type': {'key': 'type', 'type': 'ManagedServiceIdentityType'},
        'tenant_id': {'key': 'tenantId', 'type': 'str'},
        'principal_id': {'key': 'principalId', 'type': 'str'},
        'user_assigned_identities': {'key': 'userAssignedIdentities', 'type': '{UserAssignedIdentity}'},
    }

    def __init__(self, *, type=None, user_assigned_identities=None, **kwargs) -> None:
        super(ManagedServiceIdentity, self).__init__(**kwargs)
        self.type = type
        self.tenant_id = None
        self.principal_id = None
        self.user_assigned_identities = user_assigned_identities


class MetricAvailability(Model):
    """Retention policy of a resource metric.

    :param time_grain:
    :type time_grain: str
    :param blob_duration:
    :type blob_duration: str
    """

    _attribute_map = {
        'time_grain': {'key': 'timeGrain', 'type': 'str'},
        'blob_duration': {'key': 'blobDuration', 'type': 'str'},
    }

    def __init__(self, *, time_grain: str=None, blob_duration: str=None, **kwargs) -> None:
        super(MetricAvailability, self).__init__(**kwargs)
        self.time_grain = time_grain
        self.blob_duration = blob_duration


class MetricSpecification(Model):
    """Definition of a single resource metric.

    :param name:
    :type name: str
    :param display_name:
    :type display_name: str
    :param display_description:
    :type display_description: str
    :param unit:
    :type unit: str
    :param aggregation_type:
    :type aggregation_type: str
    :param supports_instance_level_aggregation:
    :type supports_instance_level_aggregation: bool
    :param enable_regional_mdm_account:
    :type enable_regional_mdm_account: bool
    :param source_mdm_account:
    :type source_mdm_account: str
    :param source_mdm_namespace:
    :type source_mdm_namespace: str
    :param metric_filter_pattern:
    :type metric_filter_pattern: str
    :param fill_gap_with_zero:
    :type fill_gap_with_zero: bool
    :param is_internal:
    :type is_internal: bool
    :param dimensions:
    :type dimensions: list[~azure.mgmt.web.v2021_02_01.models.Dimension]
    :param category:
    :type category: str
    :param availabilities:
    :type availabilities:
     list[~azure.mgmt.web.v2021_02_01.models.MetricAvailability]
    :param supported_time_grain_types:
    :type supported_time_grain_types: list[str]
    :param supported_aggregation_types:
    :type supported_aggregation_types: list[str]
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'display_name': {'key': 'displayName', 'type': 'str'},
        'display_description': {'key': 'displayDescription', 'type': 'str'},
        'unit': {'key': 'unit', 'type': 'str'},
        'aggregation_type': {'key': 'aggregationType', 'type': 'str'},
        'supports_instance_level_aggregation': {'key': 'supportsInstanceLevelAggregation', 'type': 'bool'},
        'enable_regional_mdm_account': {'key': 'enableRegionalMdmAccount', 'type': 'bool'},
        'source_mdm_account': {'key': 'sourceMdmAccount', 'type': 'str'},
        'source_mdm_namespace': {'key': 'sourceMdmNamespace', 'type': 'str'},
        'metric_filter_pattern': {'key': 'metricFilterPattern', 'type': 'str'},
        'fill_gap_with_zero': {'key': 'fillGapWithZero', 'type': 'bool'},
        'is_internal': {'key': 'isInternal', 'type': 'bool'},
        'dimensions': {'key': 'dimensions', 'type': '[Dimension]'},
        'category': {'key': 'category', 'type': 'str'},
        'availabilities': {'key': 'availabilities', 'type': '[MetricAvailability]'},
        'supported_time_grain_types': {'key': 'supportedTimeGrainTypes', 'type': '[str]'},
        'supported_aggregation_types': {'key': 'supportedAggregationTypes', 'type': '[str]'},
    }

    def __init__(self, *, name: str=None, display_name: str=None, display_description: str=None, unit: str=None, aggregation_type: str=None, supports_instance_level_aggregation: bool=None, enable_regional_mdm_account: bool=None, source_mdm_account: str=None, source_mdm_namespace: str=None, metric_filter_pattern: str=None, fill_gap_with_zero: bool=None, is_internal: bool=None, dimensions=None, category: str=None, availabilities=None, supported_time_grain_types=None, supported_aggregation_types=None, **kwargs) -> None:
        super(MetricSpecification, self).__init__(**kwargs)
        self.name = name
        self.display_name = display_name
        self.display_description = display_description
        self.unit = unit
        self.aggregation_type = aggregation_type
        self.supports_instance_level_aggregation = supports_instance_level_aggregation
        self.enable_regional_mdm_account = enable_regional_mdm_account
        self.source_mdm_account = source_mdm_account
        self.source_mdm_namespace = source_mdm_namespace
        self.metric_filter_pattern = metric_filter_pattern
        self.fill_gap_with_zero = fill_gap_with_zero
        self.is_internal = is_internal
        self.dimensions = dimensions
        self.category = category
        self.availabilities = availabilities
        self.supported_time_grain_types = supported_time_grain_types
        self.supported_aggregation_types = supported_aggregation_types


class NameIdentifier(Model):
    """Identifies an object.

    :param name: Name of the object.
    :type name: str
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
    }

    def __init__(self, *, name: str=None, **kwargs) -> None:
        super(NameIdentifier, self).__init__(**kwargs)
        self.name = name


class NameValuePair(Model):
    """Name value pair.

    :param name: Pair name.
    :type name: str
    :param value: Pair value.
    :type value: str
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'value': {'key': 'value', 'type': 'str'},
    }

    def __init__(self, *, name: str=None, value: str=None, **kwargs) -> None:
        super(NameValuePair, self).__init__(**kwargs)
        self.name = name
        self.value = value


class Operation(Model):
    """An operation on a resource.

    :param id: Operation ID.
    :type id: str
    :param name: Operation name.
    :type name: str
    :param status: The current status of the operation. Possible values
     include: 'InProgress', 'Failed', 'Succeeded', 'TimedOut', 'Created'
    :type status: str or ~azure.mgmt.web.v2021_02_01.models.OperationStatus
    :param errors: Any errors associate with the operation.
    :type errors: list[~azure.mgmt.web.v2021_02_01.models.ErrorEntity]
    :param created_time: Time when operation has started.
    :type created_time: datetime
    :param modified_time: Time when operation has been updated.
    :type modified_time: datetime
    :param expiration_time: Time when operation will expire.
    :type expiration_time: datetime
    :param geo_master_operation_id: Applicable only for stamp operation ids.
    :type geo_master_operation_id: str
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'status': {'key': 'status', 'type': 'OperationStatus'},
        'errors': {'key': 'errors', 'type': '[ErrorEntity]'},
        'created_time': {'key': 'createdTime', 'type': 'iso-8601'},
        'modified_time': {'key': 'modifiedTime', 'type': 'iso-8601'},
        'expiration_time': {'key': 'expirationTime', 'type': 'iso-8601'},
        'geo_master_operation_id': {'key': 'geoMasterOperationId', 'type': 'str'},
    }

    def __init__(self, *, id: str=None, name: str=None, status=None, errors=None, created_time=None, modified_time=None, expiration_time=None, geo_master_operation_id: str=None, **kwargs) -> None:
        super(Operation, self).__init__(**kwargs)
        self.id = id
        self.name = name
        self.status = status
        self.errors = errors
        self.created_time = created_time
        self.modified_time = modified_time
        self.expiration_time = expiration_time
        self.geo_master_operation_id = geo_master_operation_id


class PrivateEndpointConnectionCollection(Model):
    """PrivateEndpointConnectionCollection.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    All required parameters must be populated in order to send to Azure.

    :param value: Required. Collection of resources.
    :type value:
     list[~azure.mgmt.web.v2021_02_01.models.RemotePrivateEndpointConnectionARMResource]
    :ivar next_link: Link to next page of resources.
    :vartype next_link: str
    """

    _validation = {
        'value': {'required': True},
        'next_link': {'readonly': True},
    }

    _attribute_map = {
        'value': {'key': 'value', 'type': '[RemotePrivateEndpointConnectionARMResource]'},
        'next_link': {'key': 'nextLink', 'type': 'str'},
    }

    def __init__(self, *, value, **kwargs) -> None:
        super(PrivateEndpointConnectionCollection, self).__init__(**kwargs)
        self.value = value
        self.next_link = None


class PrivateLinkConnectionState(Model):
    """The state of a private link connection.

    All required parameters must be populated in order to send to Azure.

    :param status: Required. Status of a private link connection
    :type status: str
    :param description: Description of a private link connection
    :type description: str
    :param actions_required: ActionsRequired for a private link connection
    :type actions_required: str
    """

    _validation = {
        'status': {'required': True},
    }

    _attribute_map = {
        'status': {'key': 'status', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'actions_required': {'key': 'actionsRequired', 'type': 'str'},
    }

    def __init__(self, *, status: str, description: str=None, actions_required: str=None, **kwargs) -> None:
        super(PrivateLinkConnectionState, self).__init__(**kwargs)
        self.status = status
        self.description = description
        self.actions_required = actions_required


class PrivateLinkResource(Model):
    """A private link resource.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: str
    :param name: Required. Name of a private link resource
    :type name: str
    :param type: Required.
    :type type: str
    :param properties: Required. Properties of a private link resource
    :type properties:
     ~azure.mgmt.web.v2021_02_01.models.PrivateLinkResourceProperties
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
        'type': {'required': True},
        'properties': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'properties': {'key': 'properties', 'type': 'PrivateLinkResourceProperties'},
    }

    def __init__(self, *, id: str, name: str, type: str, properties, **kwargs) -> None:
        super(PrivateLinkResource, self).__init__(**kwargs)
        self.id = id
        self.name = name
        self.type = type
        self.properties = properties


class PrivateLinkResourceProperties(Model):
    """Properties of a private link resource.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar group_id: GroupId of a private link resource
    :vartype group_id: str
    :ivar required_members: RequiredMembers of a private link resource
    :vartype required_members: list[str]
    :ivar required_zone_names: RequiredZoneNames of a private link resource
    :vartype required_zone_names: list[str]
    """

    _validation = {
        'group_id': {'readonly': True},
        'required_members': {'readonly': True},
        'required_zone_names': {'readonly': True},
    }

    _attribute_map = {
        'group_id': {'key': 'groupId', 'type': 'str'},
        'required_members': {'key': 'requiredMembers', 'type': '[str]'},
        'required_zone_names': {'key': 'requiredZoneNames', 'type': '[str]'},
    }

    def __init__(self, **kwargs) -> None:
        super(PrivateLinkResourceProperties, self).__init__(**kwargs)
        self.group_id = None
        self.required_members = None
        self.required_zone_names = None


class PrivateLinkResourcesWrapper(Model):
    """Wrapper for a collection of private link resources.

    All required parameters must be populated in order to send to Azure.

    :param value: Required.
    :type value: list[~azure.mgmt.web.v2021_02_01.models.PrivateLinkResource]
    """

    _validation = {
        'value': {'required': True},
    }

    _attribute_map = {
        'value': {'key': 'value', 'type': '[PrivateLinkResource]'},
    }

    def __init__(self, *, value, **kwargs) -> None:
        super(PrivateLinkResourcesWrapper, self).__init__(**kwargs)
        self.value = value


class PushSettings(ProxyOnlyResource):
    """Push settings for the App.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    All required parameters must be populated in order to send to Azure.

    :ivar id: Resource Id.
    :vartype id: str
    :ivar name: Resource Name.
    :vartype name: str
    :param kind: Kind of resource.
    :type kind: str
    :ivar type: Resource type.
    :vartype type: str
    :param is_push_enabled: Required. Gets or sets a flag indicating whether
     the Push endpoint is enabled.
    :type is_push_enabled: bool
    :param tag_whitelist_json: Gets or sets a JSON string containing a list of
     tags that are whitelisted for use by the push registration endpoint.
    :type tag_whitelist_json: str
    :param tags_requiring_auth: Gets or sets a JSON string containing a list
     of tags that require user authentication to be used in the push
     registration endpoint.
     Tags can consist of alphanumeric characters and the following:
     '_', '@', '#', '.', ':', '-'.
     Validation should be performed at the PushRequestHandler.
    :type tags_requiring_auth: str
    :param dynamic_tags_json: Gets or sets a JSON string containing a list of
     dynamic tags that will be evaluated from user claims in the push
     registration endpoint.
    :type dynamic_tags_json: str
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
        'is_push_enabled': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'kind': {'key': 'kind', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'is_push_enabled': {'key': 'properties.isPushEnabled', 'type': 'bool'},
        'tag_whitelist_json': {'key': 'properties.tagWhitelistJson', 'type': 'str'},
        'tags_requiring_auth': {'key': 'properties.tagsRequiringAuth', 'type': 'str'},
        'dynamic_tags_json': {'key': 'properties.dynamicTagsJson', 'type': 'str'},
    }

    def __init__(self, *, is_push_enabled: bool, kind: str=None, tag_whitelist_json: str=None, tags_requiring_auth: str=None, dynamic_tags_json: str=None, **kwargs) -> None:
        super(PushSettings, self).__init__(kind=kind, **kwargs)
        self.is_push_enabled = is_push_enabled
        self.tag_whitelist_json = tag_whitelist_json
        self.tags_requiring_auth = tags_requiring_auth
        self.dynamic_tags_json = dynamic_tags_json


class QueryUtterancesResult(Model):
    """Result for utterances query.

    :param sample_utterance: A sample utterance.
    :type sample_utterance: ~azure.mgmt.web.v2021_02_01.models.SampleUtterance
    :param score: Score of a sample utterance.
    :type score: float
    """

    _attribute_map = {
        'sample_utterance': {'key': 'sampleUtterance', 'type': 'SampleUtterance'},
        'score': {'key': 'score', 'type': 'float'},
    }

    def __init__(self, *, sample_utterance=None, score: float=None, **kwargs) -> None:
        super(QueryUtterancesResult, self).__init__(**kwargs)
        self.sample_utterance = sample_utterance
        self.score = score


class QueryUtterancesResults(Model):
    """Suggested utterances where the detector can be applicable.

    :param query: Search Query.
    :type query: str
    :param results: Array of utterance results for search query.
    :type results:
     list[~azure.mgmt.web.v2021_02_01.models.QueryUtterancesResult]
    """

    _attribute_map = {
        'query': {'key': 'query', 'type': 'str'},
        'results': {'key': 'results', 'type': '[QueryUtterancesResult]'},
    }

    def __init__(self, *, query: str=None, results=None, **kwargs) -> None:
        super(QueryUtterancesResults, self).__init__(**kwargs)
        self.query = query
        self.results = results


class RampUpRule(Model):
    """Routing rules for ramp up testing. This rule allows to redirect static
    traffic % to a slot or to gradually change routing % based on performance.

    :param action_host_name: Hostname of a slot to which the traffic will be
     redirected if decided to. E.g. myapp-stage.azurewebsites.net.
    :type action_host_name: str
    :param reroute_percentage: Percentage of the traffic which will be
     redirected to <code>ActionHostName</code>.
    :type reroute_percentage: float
    :param change_step: In auto ramp up scenario this is the step to
     add/remove from <code>ReroutePercentage</code> until it reaches
     \\n<code>MinReroutePercentage</code> or
     <code>MaxReroutePercentage</code>. Site metrics are checked every N
     minutes specified in <code>ChangeIntervalInMinutes</code>.\\nCustom
     decision algorithm
     can be provided in TiPCallback site extension which URL can be specified
     in <code>ChangeDecisionCallbackUrl</code>.
    :type change_step: float
    :param change_interval_in_minutes: Specifies interval in minutes to
     reevaluate ReroutePercentage.
    :type change_interval_in_minutes: int
    :param min_reroute_percentage: Specifies lower boundary above which
     ReroutePercentage will stay.
    :type min_reroute_percentage: float
    :param max_reroute_percentage: Specifies upper boundary below which
     ReroutePercentage will stay.
    :type max_reroute_percentage: float
    :param change_decision_callback_url: Custom decision algorithm can be
     provided in TiPCallback site extension which URL can be specified. See
     TiPCallback site extension for the scaffold and contracts.
     https://www.siteextensions.net/packages/TiPCallback/
    :type change_decision_callback_url: str
    :param name: Name of the routing rule. The recommended name would be to
     point to the slot which will receive the traffic in the experiment.
    :type name: str
    """

    _attribute_map = {
        'action_host_name': {'key': 'actionHostName', 'type': 'str'},
        'reroute_percentage': {'key': 'reroutePercentage', 'type': 'float'},
        'change_step': {'key': 'changeStep', 'type': 'float'},
        'change_interval_in_minutes': {'key': 'changeIntervalInMinutes', 'type': 'int'},
        'min_reroute_percentage': {'key': 'minReroutePercentage', 'type': 'float'},
        'max_reroute_percentage': {'key': 'maxReroutePercentage', 'type': 'float'},
        'change_decision_callback_url': {'key': 'changeDecisionCallbackUrl', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
    }

    def __init__(self, *, action_host_name: str=None, reroute_percentage: float=None, change_step: float=None, change_interval_in_minutes: int=None, min_reroute_percentage: float=None, max_reroute_percentage: float=None, change_decision_callback_url: str=None, name: str=None, **kwargs) -> None:
        super(RampUpRule, self).__init__(**kwargs)
        self.action_host_name = action_host_name
        self.reroute_percentage = reroute_percentage
        self.change_step = change_step
        self.change_interval_in_minutes = change_interval_in_minutes
        self.min_reroute_percentage = min_reroute_percentage
        self.max_reroute_percentage = max_reroute_percentage
        self.change_decision_callback_url = change_decision_callback_url
        self.name = name


class RemotePrivateEndpointConnectionARMResource(ProxyOnlyResource):
    """Remote Private Endpoint Connection ARM resource.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    All required parameters must be populated in order to send to Azure.

    :ivar id: Resource Id.
    :vartype id: str
    :ivar name: Resource Name.
    :vartype name: str
    :param kind: Kind of resource.
    :type kind: str
    :ivar type: Resource type.
    :vartype type: str
    :ivar provisioning_state:
    :vartype provisioning_state: str
    :ivar private_endpoint: PrivateEndpoint of a remote private endpoint
     connection
    :vartype private_endpoint: ~azure.mgmt.web.v2021_02_01.models.ArmIdWrapper
    :param private_link_service_connection_state: Required.
    :type private_link_service_connection_state:
     ~azure.mgmt.web.v2021_02_01.models.PrivateLinkConnectionState
    :ivar ip_addresses: Private IPAddresses mapped to the remote private
     endpoint
    :vartype ip_addresses: list[str]
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
        'provisioning_state': {'readonly': True},
        'private_endpoint': {'readonly': True},
        'private_link_service_connection_state': {'required': True},
        'ip_addresses': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'kind': {'key': 'kind', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'provisioning_state': {'key': 'properties.provisioningState', 'type': 'str'},
        'private_endpoint': {'key': 'properties.privateEndpoint', 'type': 'ArmIdWrapper'},
        'private_link_service_connection_state': {'key': 'properties.privateLinkServiceConnectionState', 'type': 'PrivateLinkConnectionState'},
        'ip_addresses': {'key': 'properties.ipAddresses', 'type': '[str]'},
    }

    def __init__(self, *, private_link_service_connection_state, kind: str=None, **kwargs) -> None:
        super(RemotePrivateEndpointConnectionARMResource, self).__init__(kind=kind, **kwargs)
        self.provisioning_state = None
        self.private_endpoint = None
        self.private_link_service_connection_state = private_link_service_connection_state
        self.ip_addresses = None


class Rendering(Model):
    """Instructions for rendering the data.

    :param type: Rendering Type. Possible values include: 'NoGraph', 'Table',
     'TimeSeries', 'TimeSeriesPerInstance', 'PieChart', 'DataSummary', 'Email',
     'Insights', 'DynamicInsight', 'Markdown', 'Detector', 'DropDown', 'Card',
     'Solution', 'Guage', 'Form', 'ChangeSets', 'ChangeAnalysisOnboarding',
     'ChangesView', 'AppInsight', 'DependencyGraph', 'DownTime', 'SummaryCard',
     'SearchComponent', 'AppInsightEnablement'
    :type type: str or ~azure.mgmt.web.v2021_02_01.models.RenderingType
    :param title: Title of data
    :type title: str
    :param description: Description of the data that will help it be
     interpreted
    :type description: str
    """

    _attribute_map = {
        'type': {'key': 'type', 'type': 'RenderingType'},
        'title': {'key': 'title', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
    }

    def __init__(self, *, type=None, title: str=None, description: str=None, **kwargs) -> None:
        super(Rendering, self).__init__(**kwargs)
        self.type = type
        self.title = title
        self.description = description


class RequestsBasedTrigger(Model):
    """Trigger based on total requests.

    :param count: Request Count.
    :type count: int
    :param time_interval: Time interval.
    :type time_interval: str
    """

    _attribute_map = {
        'count': {'key': 'count', 'type': 'int'},
        'time_interval': {'key': 'timeInterval', 'type': 'str'},
    }

    def __init__(self, *, count: int=None, time_interval: str=None, **kwargs) -> None:
        super(RequestsBasedTrigger, self).__init__(**kwargs)
        self.count = count
        self.time_interval = time_interval


class SampleUtterance(Model):
    """Sample utterance.

    :param text: Text attribute of sample utterance.
    :type text: str
    :param links: Links attribute of sample utterance.
    :type links: list[str]
    :param qid: Question id of sample utterance (for stackoverflow questions
     titles).
    :type qid: str
    """

    _attribute_map = {
        'text': {'key': 'text', 'type': 'str'},
        'links': {'key': 'links', 'type': '[str]'},
        'qid': {'key': 'qid', 'type': 'str'},
    }

    def __init__(self, *, text: str=None, links=None, qid: str=None, **kwargs) -> None:
        super(SampleUtterance, self).__init__(**kwargs)
        self.text = text
        self.links = links
        self.qid = qid


class ServiceSpecification(Model):
    """Resource metrics service provided by Microsoft.Insights resource provider.

    :param metric_specifications:
    :type metric_specifications:
     list[~azure.mgmt.web.v2021_02_01.models.MetricSpecification]
    :param log_specifications:
    :type log_specifications:
     list[~azure.mgmt.web.v2021_02_01.models.LogSpecification]
    """

    _attribute_map = {
        'metric_specifications': {'key': 'metricSpecifications', 'type': '[MetricSpecification]'},
        'log_specifications': {'key': 'logSpecifications', 'type': '[LogSpecification]'},
    }

    def __init__(self, *, metric_specifications=None, log_specifications=None, **kwargs) -> None:
        super(ServiceSpecification, self).__init__(**kwargs)
        self.metric_specifications = metric_specifications
        self.log_specifications = log_specifications


class Site(Resource):
    """A web app, a mobile app backend, or an API app.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    All required parameters must be populated in order to send to Azure.

    :ivar id: Resource Id.
    :vartype id: str
    :ivar name: Resource Name.
    :vartype name: str
    :param kind: Kind of resource.
    :type kind: str
    :param location: Required. Resource Location.
    :type location: str
    :ivar type: Resource type.
    :vartype type: str
    :param tags: Resource tags.
    :type tags: dict[str, str]
    :ivar state: Current state of the app.
    :vartype state: str
    :ivar host_names: Hostnames associated with the app.
    :vartype host_names: list[str]
    :ivar repository_site_name: Name of the repository site.
    :vartype repository_site_name: str
    :ivar usage_state: State indicating whether the app has exceeded its quota
     usage. Read-only. Possible values include: 'Normal', 'Exceeded'
    :vartype usage_state: str or ~azure.mgmt.web.v2021_02_01.models.UsageState
    :param enabled: <code>true</code> if the app is enabled; otherwise,
     <code>false</code>. Setting this value to false disables the app (takes
     the app offline).
    :type enabled: bool
    :ivar enabled_host_names: Enabled hostnames for the app.Hostnames need to
     be assigned (see HostNames) AND enabled. Otherwise,
     the app is not served on those hostnames.
    :vartype enabled_host_names: list[str]
    :ivar availability_state: Management information availability state for
     the app. Possible values include: 'Normal', 'Limited',
     'DisasterRecoveryMode'
    :vartype availability_state: str or
     ~azure.mgmt.web.v2021_02_01.models.SiteAvailabilityState
    :param host_name_ssl_states: Hostname SSL states are used to manage the
     SSL bindings for app's hostnames.
    :type host_name_ssl_states:
     list[~azure.mgmt.web.v2021_02_01.models.HostNameSslState]
    :param server_farm_id: Resource ID of the associated App Service plan,
     formatted as:
     "/subscriptions/{subscriptionID}/resourceGroups/{groupName}/providers/Microsoft.Web/serverfarms/{appServicePlanName}".
    :type server_farm_id: str
    :param reserved: <code>true</code> if reserved; otherwise,
     <code>false</code>. Default value: False .
    :type reserved: bool
    :param is_xenon: Obsolete: Hyper-V sandbox. Default value: False .
    :type is_xenon: bool
    :param hyper_v: Hyper-V sandbox. Default value: False .
    :type hyper_v: bool
    :ivar last_modified_time_utc: Last time the app was modified, in UTC.
     Read-only.
    :vartype last_modified_time_utc: datetime
    :param secrets_collection:
    :type secrets_collection:
     list[~azure.mgmt.web.v2021_02_01.models.SiteSecretInfoConfig]
    :param site_config: Configuration of the app.
    :type site_config: ~azure.mgmt.web.v2021_02_01.models.SiteConfig
    :ivar traffic_manager_host_names: Azure Traffic Manager hostnames
     associated with the app. Read-only.
    :vartype traffic_manager_host_names: list[str]
    :param scm_site_also_stopped: <code>true</code> to stop SCM (KUDU) site
     when the app is stopped; otherwise, <code>false</code>. The default is
     <code>false</code>. Default value: False .
    :type scm_site_also_stopped: bool
    :ivar target_swap_slot: Specifies which deployment slot this app will swap
     into. Read-only.
    :vartype target_swap_slot: str
    :param hosting_environment_profile: App Service Environment to use for the
     app.
    :type hosting_environment_profile:
     ~azure.mgmt.web.v2021_02_01.models.HostingEnvironmentProfile
    :param client_affinity_enabled: <code>true</code> to enable client
     affinity; <code>false</code> to stop sending session affinity cookies,
     which route client requests in the same session to the same instance.
     Default is <code>true</code>.
    :type client_affinity_enabled: bool
    :param client_cert_enabled: <code>true</code> to enable client certificate
     authentication (TLS mutual authentication); otherwise, <code>false</code>.
     Default is <code>false</code>.
    :type client_cert_enabled: bool
    :param client_cert_mode: This composes with ClientCertEnabled setting.
     - ClientCertEnabled: false means ClientCert is ignored.
     - ClientCertEnabled: true and ClientCertMode: Required means ClientCert is
     required.
     - ClientCertEnabled: true and ClientCertMode: Optional means ClientCert is
     optional or accepted. Possible values include: 'Required', 'Optional',
     'OptionalInteractiveUser'
    :type client_cert_mode: str or
     ~azure.mgmt.web.v2021_02_01.models.ClientCertMode
    :param client_cert_exclusion_paths: client certificate authentication
     comma-separated exclusion paths
    :type client_cert_exclusion_paths: str
    :param host_names_disabled: <code>true</code> to disable the public
     hostnames of the app; otherwise, <code>false</code>.
     If <code>true</code>, the app is only accessible via API management
     process.
    :type host_names_disabled: bool
    :param custom_domain_verification_id: Unique identifier that verifies the
     custom domains assigned to the app. Customer will add this id to a txt
     record for verification.
    :type custom_domain_verification_id: str
    :ivar outbound_ip_addresses: List of IP addresses that the app uses for
     outbound connections (e.g. database access). Includes VIPs from tenants
     that site can be hosted with current settings. Read-only.
    :vartype outbound_ip_addresses: str
    :ivar possible_outbound_ip_addresses: List of IP addresses that the app
     uses for outbound connections (e.g. database access). Includes VIPs from
     all tenants except dataComponent. Read-only.
    :vartype possible_outbound_ip_addresses: str
    :param container_size: Size of the function container.
    :type container_size: int
    :param daily_memory_time_quota: Maximum allowed daily memory-time quota
     (applicable on dynamic apps only).
    :type daily_memory_time_quota: int
    :ivar suspended_till: App suspended till in case memory-time quota is
     exceeded.
    :vartype suspended_till: datetime
    :ivar max_number_of_workers: Maximum number of workers.
     This only applies to Functions container.
    :vartype max_number_of_workers: int
    :param cloning_info: If specified during app creation, the app is cloned
     from a source app.
    :type cloning_info: ~azure.mgmt.web.v2021_02_01.models.CloningInfo
    :ivar resource_group: Name of the resource group the app belongs to.
     Read-only.
    :vartype resource_group: str
    :ivar is_default_container: <code>true</code> if the app is a default
     container; otherwise, <code>false</code>.
    :vartype is_default_container: bool
    :ivar default_host_name: Default hostname of the app. Read-only.
    :vartype default_host_name: str
    :ivar slot_swap_status: Status of the last deployment slot swap operation.
    :vartype slot_swap_status:
     ~azure.mgmt.web.v2021_02_01.models.SlotSwapStatus
    :param https_only: HttpsOnly: configures a web site to accept only https
     requests. Issues redirect for
     http requests
    :type https_only: bool
    :param redundancy_mode: Site redundancy mode. Possible values include:
     'None', 'Manual', 'Failover', 'ActiveActive', 'GeoRedundant'
    :type redundancy_mode: str or
     ~azure.mgmt.web.v2021_02_01.models.RedundancyMode
    :ivar in_progress_operation_id: Specifies an operation id if this site has
     a pending operation.
    :vartype in_progress_operation_id: str
    :param storage_account_required: Checks if Customer provided storage
     account is required
    :type storage_account_required: bool
    :param virtual_network_subnet_id: Azure Resource Manager ID of the Virtual
     network and subnet to be joined by Regional VNET Integration.
     This must be of the form
     /subscriptions/{subscriptionName}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworks/{vnetName}/subnets/{subnetName}
    :type virtual_network_subnet_id: str
    :param key_vault_reference_identity: Identity to use for Key Vault
     Reference authentication.
    :type key_vault_reference_identity: str
    :param identity:
    :type identity: ~azure.mgmt.web.v2021_02_01.models.ManagedServiceIdentity
    :param extended_location:
    :type extended_location:
     ~azure.mgmt.web.v2021_02_01.models.ExtendedLocation
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'location': {'required': True},
        'type': {'readonly': True},
        'state': {'readonly': True},
        'host_names': {'readonly': True},
        'repository_site_name': {'readonly': True},
        'usage_state': {'readonly': True},
        'enabled_host_names': {'readonly': True},
        'availability_state': {'readonly': True},
        'last_modified_time_utc': {'readonly': True},
        'traffic_manager_host_names': {'readonly': True},
        'target_swap_slot': {'readonly': True},
        'outbound_ip_addresses': {'readonly': True},
        'possible_outbound_ip_addresses': {'readonly': True},
        'suspended_till': {'readonly': True},
        'max_number_of_workers': {'readonly': True},
        'resource_group': {'readonly': True},
        'is_default_container': {'readonly': True},
        'default_host_name': {'readonly': True},
        'slot_swap_status': {'readonly': True},
        'in_progress_operation_id': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'kind': {'key': 'kind', 'type': 'str'},
        'location': {'key': 'location', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'tags': {'key': 'tags', 'type': '{str}'},
        'state': {'key': 'properties.state', 'type': 'str'},
        'host_names': {'key': 'properties.hostNames', 'type': '[str]'},
        'repository_site_name': {'key': 'properties.repositorySiteName', 'type': 'str'},
        'usage_state': {'key': 'properties.usageState', 'type': 'UsageState'},
        'enabled': {'key': 'properties.enabled', 'type': 'bool'},
        'enabled_host_names': {'key': 'properties.enabledHostNames', 'type': '[str]'},
        'availability_state': {'key': 'properties.availabilityState', 'type': 'SiteAvailabilityState'},
        'host_name_ssl_states': {'key': 'properties.hostNameSslStates', 'type': '[HostNameSslState]'},
        'server_farm_id': {'key': 'properties.serverFarmId', 'type': 'str'},
        'reserved': {'key': 'properties.reserved', 'type': 'bool'},
        'is_xenon': {'key': 'properties.isXenon', 'type': 'bool'},
        'hyper_v': {'key': 'properties.hyperV', 'type': 'bool'},
        'last_modified_time_utc': {'key': 'properties.lastModifiedTimeUtc', 'type': 'iso-8601'},
        'secrets_collection': {'key': 'properties.secretsCollection', 'type': '[SiteSecretInfoConfig]'},
        'site_config': {'key': 'properties.siteConfig', 'type': 'SiteConfig'},
        'traffic_manager_host_names': {'key': 'properties.trafficManagerHostNames', 'type': '[str]'},
        'scm_site_also_stopped': {'key': 'properties.scmSiteAlsoStopped', 'type': 'bool'},
        'target_swap_slot': {'key': 'properties.targetSwapSlot', 'type': 'str'},
        'hosting_environment_profile': {'key': 'properties.hostingEnvironmentProfile', 'type': 'HostingEnvironmentProfile'},
        'client_affinity_enabled': {'key': 'properties.clientAffinityEnabled', 'type': 'bool'},
        'client_cert_enabled': {'key': 'properties.clientCertEnabled', 'type': 'bool'},
        'client_cert_mode': {'key': 'properties.clientCertMode', 'type': 'ClientCertMode'},
        'client_cert_exclusion_paths': {'key': 'properties.clientCertExclusionPaths', 'type': 'str'},
        'host_names_disabled': {'key': 'properties.hostNamesDisabled', 'type': 'bool'},
        'custom_domain_verification_id': {'key': 'properties.customDomainVerificationId', 'type': 'str'},
        'outbound_ip_addresses': {'key': 'properties.outboundIpAddresses', 'type': 'str'},
        'possible_outbound_ip_addresses': {'key': 'properties.possibleOutboundIpAddresses', 'type': 'str'},
        'container_size': {'key': 'properties.containerSize', 'type': 'int'},
        'daily_memory_time_quota': {'key': 'properties.dailyMemoryTimeQuota', 'type': 'int'},
        'suspended_till': {'key': 'properties.suspendedTill', 'type': 'iso-8601'},
        'max_number_of_workers': {'key': 'properties.maxNumberOfWorkers', 'type': 'int'},
        'cloning_info': {'key': 'properties.cloningInfo', 'type': 'CloningInfo'},
        'resource_group': {'key': 'properties.resourceGroup', 'type': 'str'},
        'is_default_container': {'key': 'properties.isDefaultContainer', 'type': 'bool'},
        'default_host_name': {'key': 'properties.defaultHostName', 'type': 'str'},
        'slot_swap_status': {'key': 'properties.slotSwapStatus', 'type': 'SlotSwapStatus'},
        'https_only': {'key': 'properties.httpsOnly', 'type': 'bool'},
        'redundancy_mode': {'key': 'properties.redundancyMode', 'type': 'RedundancyMode'},
        'in_progress_operation_id': {'key': 'properties.inProgressOperationId', 'type': 'str'},
        'storage_account_required': {'key': 'properties.storageAccountRequired', 'type': 'bool'},
        'virtual_network_subnet_id': {'key': 'properties.virtualNetworkSubnetId', 'type': 'str'},
        'key_vault_reference_identity': {'key': 'properties.keyVaultReferenceIdentity', 'type': 'str'},
        'identity': {'key': 'identity', 'type': 'ManagedServiceIdentity'},
        'extended_location': {'key': 'extendedLocation', 'type': 'ExtendedLocation'},
    }

    def __init__(self, *, location: str, kind: str=None, tags=None, enabled: bool=None, host_name_ssl_states=None, server_farm_id: str=None, reserved: bool=False, is_xenon: bool=False, hyper_v: bool=False, secrets_collection=None, site_config=None, scm_site_also_stopped: bool=False, hosting_environment_profile=None, client_affinity_enabled: bool=None, client_cert_enabled: bool=None, client_cert_mode=None, client_cert_exclusion_paths: str=None, host_names_disabled: bool=None, custom_domain_verification_id: str=None, container_size: int=None, daily_memory_time_quota: int=None, cloning_info=None, https_only: bool=None, redundancy_mode=None, storage_account_required: bool=None, virtual_network_subnet_id: str=None, key_vault_reference_identity: str=None, identity=None, extended_location=None, **kwargs) -> None:
        super(Site, self).__init__(kind=kind, location=location, tags=tags, **kwargs)
        self.state = None
        self.host_names = None
        self.repository_site_name = None
        self.usage_state = None
        self.enabled = enabled
        self.enabled_host_names = None
        self.availability_state = None
        self.host_name_ssl_states = host_name_ssl_states
        self.server_farm_id = server_farm_id
        self.reserved = reserved
        self.is_xenon = is_xenon
        self.hyper_v = hyper_v
        self.last_modified_time_utc = None
        self.secrets_collection = secrets_collection
        self.site_config = site_config
        self.traffic_manager_host_names = None
        self.scm_site_also_stopped = scm_site_also_stopped
        self.target_swap_slot = None
        self.hosting_environment_profile = hosting_environment_profile
        self.client_affinity_enabled = client_affinity_enabled
        self.client_cert_enabled = client_cert_enabled
        self.client_cert_mode = client_cert_mode
        self.client_cert_exclusion_paths = client_cert_exclusion_paths
        self.host_names_disabled = host_names_disabled
        self.custom_domain_verification_id = custom_domain_verification_id
        self.outbound_ip_addresses = None
        self.possible_outbound_ip_addresses = None
        self.container_size = container_size
        self.daily_memory_time_quota = daily_memory_time_quota
        self.suspended_till = None
        self.max_number_of_workers = None
        self.cloning_info = cloning_info
        self.resource_group = None
        self.is_default_container = None
        self.default_host_name = None
        self.slot_swap_status = None
        self.https_only = https_only
        self.redundancy_mode = redundancy_mode
        self.in_progress_operation_id = None
        self.storage_account_required = storage_account_required
        self.virtual_network_subnet_id = virtual_network_subnet_id
        self.key_vault_reference_identity = key_vault_reference_identity
        self.identity = identity
        self.extended_location = extended_location


class SiteConfig(Model):
    """Configuration of an App Service app.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param number_of_workers: Number of workers.
    :type number_of_workers: int
    :param default_documents: Default documents.
    :type default_documents: list[str]
    :param net_framework_version: .NET Framework version. Default value:
     "v4.6" .
    :type net_framework_version: str
    :param php_version: Version of PHP.
    :type php_version: str
    :param python_version: Version of Python.
    :type python_version: str
    :param node_version: Version of Node.js.
    :type node_version: str
    :param power_shell_version: Version of PowerShell.
    :type power_shell_version: str
    :param linux_fx_version: Linux App Framework and version
    :type linux_fx_version: str
    :param windows_fx_version: Xenon App Framework and version
    :type windows_fx_version: str
    :param request_tracing_enabled: <code>true</code> if request tracing is
     enabled; otherwise, <code>false</code>.
    :type request_tracing_enabled: bool
    :param request_tracing_expiration_time: Request tracing expiration time.
    :type request_tracing_expiration_time: datetime
    :param remote_debugging_enabled: <code>true</code> if remote debugging is
     enabled; otherwise, <code>false</code>.
    :type remote_debugging_enabled: bool
    :param remote_debugging_version: Remote debugging version.
    :type remote_debugging_version: str
    :param http_logging_enabled: <code>true</code> if HTTP logging is enabled;
     otherwise, <code>false</code>.
    :type http_logging_enabled: bool
    :param logs_directory_size_limit: HTTP logs directory size limit.
    :type logs_directory_size_limit: int
    :param detailed_error_logging_enabled: <code>true</code> if detailed error
     logging is enabled; otherwise, <code>false</code>.
    :type detailed_error_logging_enabled: bool
    :param publishing_username: Publishing user name.
    :type publishing_username: str
    :param app_settings: Application settings.
    :type app_settings: list[~azure.mgmt.web.v2021_02_01.models.NameValuePair]
    :param connection_strings: Connection strings.
    :type connection_strings:
     list[~azure.mgmt.web.v2021_02_01.models.ConnStringInfo]
    :ivar machine_key: Site MachineKey.
    :vartype machine_key: ~azure.mgmt.web.v2021_02_01.models.SiteMachineKey
    :param handler_mappings: Handler mappings.
    :type handler_mappings:
     list[~azure.mgmt.web.v2021_02_01.models.HandlerMapping]
    :param document_root: Document root.
    :type document_root: str
    :param scm_type: SCM type. Possible values include: 'None', 'Dropbox',
     'Tfs', 'LocalGit', 'GitHub', 'CodePlexGit', 'CodePlexHg', 'BitbucketGit',
     'BitbucketHg', 'ExternalGit', 'ExternalHg', 'OneDrive', 'VSO', 'VSTSRM'
    :type scm_type: str or ~azure.mgmt.web.v2021_02_01.models.ScmType
    :param use32_bit_worker_process: <code>true</code> to use 32-bit worker
     process; otherwise, <code>false</code>.
    :type use32_bit_worker_process: bool
    :param web_sockets_enabled: <code>true</code> if WebSocket is enabled;
     otherwise, <code>false</code>.
    :type web_sockets_enabled: bool
    :param always_on: <code>true</code> if Always On is enabled; otherwise,
     <code>false</code>.
    :type always_on: bool
    :param java_version: Java version.
    :type java_version: str
    :param java_container: Java container.
    :type java_container: str
    :param java_container_version: Java container version.
    :type java_container_version: str
    :param app_command_line: App command line to launch.
    :type app_command_line: str
    :param managed_pipeline_mode: Managed pipeline mode. Possible values
     include: 'Integrated', 'Classic'
    :type managed_pipeline_mode: str or
     ~azure.mgmt.web.v2021_02_01.models.ManagedPipelineMode
    :param virtual_applications: Virtual applications.
    :type virtual_applications:
     list[~azure.mgmt.web.v2021_02_01.models.VirtualApplication]
    :param load_balancing: Site load balancing. Possible values include:
     'WeightedRoundRobin', 'LeastRequests', 'LeastResponseTime',
     'WeightedTotalTraffic', 'RequestHash', 'PerSiteRoundRobin'
    :type load_balancing: str or
     ~azure.mgmt.web.v2021_02_01.models.SiteLoadBalancing
    :param experiments: This is work around for polymorphic types.
    :type experiments: ~azure.mgmt.web.v2021_02_01.models.Experiments
    :param limits: Site limits.
    :type limits: ~azure.mgmt.web.v2021_02_01.models.SiteLimits
    :param auto_heal_enabled: <code>true</code> if Auto Heal is enabled;
     otherwise, <code>false</code>.
    :type auto_heal_enabled: bool
    :param auto_heal_rules: Auto Heal rules.
    :type auto_heal_rules: ~azure.mgmt.web.v2021_02_01.models.AutoHealRules
    :param tracing_options: Tracing options.
    :type tracing_options: str
    :param vnet_name: Virtual Network name.
    :type vnet_name: str
    :param vnet_route_all_enabled: Virtual Network Route All enabled. This
     causes all outbound traffic to have Virtual Network Security Groups and
     User Defined Routes applied.
    :type vnet_route_all_enabled: bool
    :param vnet_private_ports_count: The number of private ports assigned to
     this app. These will be assigned dynamically on runtime.
    :type vnet_private_ports_count: int
    :param public_network_access: Property to allow or block all public
     trafic.
    :type public_network_access: str
    :param cors: Cross-Origin Resource Sharing (CORS) settings.
    :type cors: ~azure.mgmt.web.v2021_02_01.models.CorsSettings
    :param push: Push endpoint settings.
    :type push: ~azure.mgmt.web.v2021_02_01.models.PushSettings
    :param api_definition: Information about the formal API definition for the
     app.
    :type api_definition: ~azure.mgmt.web.v2021_02_01.models.ApiDefinitionInfo
    :param api_management_config: Azure API management settings linked to the
     app.
    :type api_management_config:
     ~azure.mgmt.web.v2021_02_01.models.ApiManagementConfig
    :param auto_swap_slot_name: Auto-swap slot name.
    :type auto_swap_slot_name: str
    :param local_my_sql_enabled: <code>true</code> to enable local MySQL;
     otherwise, <code>false</code>. Default value: False .
    :type local_my_sql_enabled: bool
    :param managed_service_identity_id: Managed Service Identity Id
    :type managed_service_identity_id: int
    :param x_managed_service_identity_id: Explicit Managed Service Identity Id
    :type x_managed_service_identity_id: int
    :param key_vault_reference_identity: Identity to use for Key Vault
     Reference authentication.
    :type key_vault_reference_identity: str
    :param ip_security_restrictions: IP security restrictions for main.
    :type ip_security_restrictions:
     list[~azure.mgmt.web.v2021_02_01.models.IpSecurityRestriction]
    :param scm_ip_security_restrictions: IP security restrictions for scm.
    :type scm_ip_security_restrictions:
     list[~azure.mgmt.web.v2021_02_01.models.IpSecurityRestriction]
    :param scm_ip_security_restrictions_use_main: IP security restrictions for
     scm to use main.
    :type scm_ip_security_restrictions_use_main: bool
    :param http20_enabled: Http20Enabled: configures a web site to allow
     clients to connect over http2.0. Default value: True .
    :type http20_enabled: bool
    :param min_tls_version: MinTlsVersion: configures the minimum version of
     TLS required for SSL requests. Possible values include: '1.0', '1.1',
     '1.2'
    :type min_tls_version: str or
     ~azure.mgmt.web.v2021_02_01.models.SupportedTlsVersions
    :param scm_min_tls_version: ScmMinTlsVersion: configures the minimum
     version of TLS required for SSL requests for SCM site. Possible values
     include: '1.0', '1.1', '1.2'
    :type scm_min_tls_version: str or
     ~azure.mgmt.web.v2021_02_01.models.SupportedTlsVersions
    :param ftps_state: State of FTP / FTPS service. Possible values include:
     'AllAllowed', 'FtpsOnly', 'Disabled'
    :type ftps_state: str or ~azure.mgmt.web.v2021_02_01.models.FtpsState
    :param pre_warmed_instance_count: Number of preWarmed instances.
     This setting only applies to the Consumption and Elastic Plans
    :type pre_warmed_instance_count: int
    :param function_app_scale_limit: Maximum number of workers that a site can
     scale out to.
     This setting only applies to the Consumption and Elastic Premium Plans
    :type function_app_scale_limit: int
    :param health_check_path: Health check path
    :type health_check_path: str
    :param functions_runtime_scale_monitoring_enabled: Gets or sets a value
     indicating whether functions runtime scale monitoring is enabled. When
     enabled,
     the ScaleController will not monitor event sources directly, but will
     instead call to the
     runtime to get scale status.
    :type functions_runtime_scale_monitoring_enabled: bool
    :param website_time_zone: Sets the time zone a site uses for generating
     timestamps. Compatible with Linux and Windows App Service. Setting the
     WEBSITE_TIME_ZONE app setting takes precedence over this config. For
     Linux, expects tz database values https://www.iana.org/time-zones (for a
     quick reference see
     https://en.wikipedia.org/wiki/List_of_tz_database_time_zones). For
     Windows, expects one of the time zones listed under
     HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Windows NT\\CurrentVersion\\Time
     Zones
    :type website_time_zone: str
    :param minimum_elastic_instance_count: Number of minimum instance count
     for a site
     This setting only applies to the Elastic Plans
    :type minimum_elastic_instance_count: int
    :param azure_storage_accounts: List of Azure Storage Accounts.
    :type azure_storage_accounts: dict[str,
     ~azure.mgmt.web.v2021_02_01.models.AzureStorageInfoValue]
    :param http20_proxy_flag: Configures the website to allow http/2.0
     requests to pass through using plain text
     Useful for the gRPC scenario
    :type http20_proxy_flag: int
    :param site_port: Port setting for a WebApp. If this setting exists, it
     will be preferred over
     WEBSITES_PORT, CONTAINER_PORT or PORT set in the appSettings.
     Hyper-V Containers: Zero means no HTTP endpoint for Hyper-V Background
     Containers.
    :type site_port: int
    :param antivirus_scan_enabled: Enables the Antivirus Audit Logs
    :type antivirus_scan_enabled: bool
    """

    _validation = {
        'machine_key': {'readonly': True},
        'pre_warmed_instance_count': {'maximum': 10, 'minimum': 0},
        'function_app_scale_limit': {'minimum': 0},
        'minimum_elastic_instance_count': {'maximum': 20, 'minimum': 0},
        'site_port': {'maximum': 65535, 'minimum': 0},
    }

    _attribute_map = {
        'number_of_workers': {'key': 'numberOfWorkers', 'type': 'int'},
        'default_documents': {'key': 'defaultDocuments', 'type': '[str]'},
        'net_framework_version': {'key': 'netFrameworkVersion', 'type': 'str'},
        'php_version': {'key': 'phpVersion', 'type': 'str'},
        'python_version': {'key': 'pythonVersion', 'type': 'str'},
        'node_version': {'key': 'nodeVersion', 'type': 'str'},
        'power_shell_version': {'key': 'powerShellVersion', 'type': 'str'},
        'linux_fx_version': {'key': 'linuxFxVersion', 'type': 'str'},
        'windows_fx_version': {'key': 'windowsFxVersion', 'type': 'str'},
        'request_tracing_enabled': {'key': 'requestTracingEnabled', 'type': 'bool'},
        'request_tracing_expiration_time': {'key': 'requestTracingExpirationTime', 'type': 'iso-8601'},
        'remote_debugging_enabled': {'key': 'remoteDebuggingEnabled', 'type': 'bool'},
        'remote_debugging_version': {'key': 'remoteDebuggingVersion', 'type': 'str'},
        'http_logging_enabled': {'key': 'httpLoggingEnabled', 'type': 'bool'},
        'logs_directory_size_limit': {'key': 'logsDirectorySizeLimit', 'type': 'int'},
        'detailed_error_logging_enabled': {'key': 'detailedErrorLoggingEnabled', 'type': 'bool'},
        'publishing_username': {'key': 'publishingUsername', 'type': 'str'},
        'app_settings': {'key': 'appSettings', 'type': '[NameValuePair]'},
        'connection_strings': {'key': 'connectionStrings', 'type': '[ConnStringInfo]'},
        'machine_key': {'key': 'machineKey', 'type': 'SiteMachineKey'},
        'handler_mappings': {'key': 'handlerMappings', 'type': '[HandlerMapping]'},
        'document_root': {'key': 'documentRoot', 'type': 'str'},
        'scm_type': {'key': 'scmType', 'type': 'str'},
        'use32_bit_worker_process': {'key': 'use32BitWorkerProcess', 'type': 'bool'},
        'web_sockets_enabled': {'key': 'webSocketsEnabled', 'type': 'bool'},
        'always_on': {'key': 'alwaysOn', 'type': 'bool'},
        'java_version': {'key': 'javaVersion', 'type': 'str'},
        'java_container': {'key': 'javaContainer', 'type': 'str'},
        'java_container_version': {'key': 'javaContainerVersion', 'type': 'str'},
        'app_command_line': {'key': 'appCommandLine', 'type': 'str'},
        'managed_pipeline_mode': {'key': 'managedPipelineMode', 'type': 'ManagedPipelineMode'},
        'virtual_applications': {'key': 'virtualApplications', 'type': '[VirtualApplication]'},
        'load_balancing': {'key': 'loadBalancing', 'type': 'SiteLoadBalancing'},
        'experiments': {'key': 'experiments', 'type': 'Experiments'},
        'limits': {'key': 'limits', 'type': 'SiteLimits'},
        'auto_heal_enabled': {'key': 'autoHealEnabled', 'type': 'bool'},
        'auto_heal_rules': {'key': 'autoHealRules', 'type': 'AutoHealRules'},
        'tracing_options': {'key': 'tracingOptions', 'type': 'str'},
        'vnet_name': {'key': 'vnetName', 'type': 'str'},
        'vnet_route_all_enabled': {'key': 'vnetRouteAllEnabled', 'type': 'bool'},
        'vnet_private_ports_count': {'key': 'vnetPrivatePortsCount', 'type': 'int'},
        'public_network_access': {'key': 'publicNetworkAccess', 'type': 'str'},
        'cors': {'key': 'cors', 'type': 'CorsSettings'},
        'push': {'key': 'push', 'type': 'PushSettings'},
        'api_definition': {'key': 'apiDefinition', 'type': 'ApiDefinitionInfo'},
        'api_management_config': {'key': 'apiManagementConfig', 'type': 'ApiManagementConfig'},
        'auto_swap_slot_name': {'key': 'autoSwapSlotName', 'type': 'str'},
        'local_my_sql_enabled': {'key': 'localMySqlEnabled', 'type': 'bool'},
        'managed_service_identity_id': {'key': 'managedServiceIdentityId', 'type': 'int'},
        'x_managed_service_identity_id': {'key': 'xManagedServiceIdentityId', 'type': 'int'},
        'key_vault_reference_identity': {'key': 'keyVaultReferenceIdentity', 'type': 'str'},
        'ip_security_restrictions': {'key': 'ipSecurityRestrictions', 'type': '[IpSecurityRestriction]'},
        'scm_ip_security_restrictions': {'key': 'scmIpSecurityRestrictions', 'type': '[IpSecurityRestriction]'},
        'scm_ip_security_restrictions_use_main': {'key': 'scmIpSecurityRestrictionsUseMain', 'type': 'bool'},
        'http20_enabled': {'key': 'http20Enabled', 'type': 'bool'},
        'min_tls_version': {'key': 'minTlsVersion', 'type': 'str'},
        'scm_min_tls_version': {'key': 'scmMinTlsVersion', 'type': 'str'},
        'ftps_state': {'key': 'ftpsState', 'type': 'str'},
        'pre_warmed_instance_count': {'key': 'preWarmedInstanceCount', 'type': 'int'},
        'function_app_scale_limit': {'key': 'functionAppScaleLimit', 'type': 'int'},
        'health_check_path': {'key': 'healthCheckPath', 'type': 'str'},
        'functions_runtime_scale_monitoring_enabled': {'key': 'functionsRuntimeScaleMonitoringEnabled', 'type': 'bool'},
        'website_time_zone': {'key': 'websiteTimeZone', 'type': 'str'},
        'minimum_elastic_instance_count': {'key': 'minimumElasticInstanceCount', 'type': 'int'},
        'azure_storage_accounts': {'key': 'azureStorageAccounts', 'type': '{AzureStorageInfoValue}'},
        'http20_proxy_flag': {'key': 'http20ProxyFlag', 'type': 'int'},
        'site_port': {'key': 'sitePort', 'type': 'int'},
        'antivirus_scan_enabled': {'key': 'antivirusScanEnabled', 'type': 'bool'},
    }

    def __init__(self, *, number_of_workers: int=None, default_documents=None, net_framework_version: str="v4.6", php_version: str=None, python_version: str=None, node_version: str=None, power_shell_version: str=None, linux_fx_version: str=None, windows_fx_version: str=None, request_tracing_enabled: bool=None, request_tracing_expiration_time=None, remote_debugging_enabled: bool=None, remote_debugging_version: str=None, http_logging_enabled: bool=None, logs_directory_size_limit: int=None, detailed_error_logging_enabled: bool=None, publishing_username: str=None, app_settings=None, connection_strings=None, handler_mappings=None, document_root: str=None, scm_type=None, use32_bit_worker_process: bool=None, web_sockets_enabled: bool=None, always_on: bool=None, java_version: str=None, java_container: str=None, java_container_version: str=None, app_command_line: str=None, managed_pipeline_mode=None, virtual_applications=None, load_balancing=None, experiments=None, limits=None, auto_heal_enabled: bool=None, auto_heal_rules=None, tracing_options: str=None, vnet_name: str=None, vnet_route_all_enabled: bool=None, vnet_private_ports_count: int=None, public_network_access: str=None, cors=None, push=None, api_definition=None, api_management_config=None, auto_swap_slot_name: str=None, local_my_sql_enabled: bool=False, managed_service_identity_id: int=None, x_managed_service_identity_id: int=None, key_vault_reference_identity: str=None, ip_security_restrictions=None, scm_ip_security_restrictions=None, scm_ip_security_restrictions_use_main: bool=None, http20_enabled: bool=True, min_tls_version=None, scm_min_tls_version=None, ftps_state=None, pre_warmed_instance_count: int=None, function_app_scale_limit: int=None, health_check_path: str=None, functions_runtime_scale_monitoring_enabled: bool=None, website_time_zone: str=None, minimum_elastic_instance_count: int=None, azure_storage_accounts=None, http20_proxy_flag: int=None, site_port: int=None, antivirus_scan_enabled: bool=None, **kwargs) -> None:
        super(SiteConfig, self).__init__(**kwargs)
        self.number_of_workers = number_of_workers
        self.default_documents = default_documents
        self.net_framework_version = net_framework_version
        self.php_version = php_version
        self.python_version = python_version
        self.node_version = node_version
        self.power_shell_version = power_shell_version
        self.linux_fx_version = linux_fx_version
        self.windows_fx_version = windows_fx_version
        self.request_tracing_enabled = request_tracing_enabled
        self.request_tracing_expiration_time = request_tracing_expiration_time
        self.remote_debugging_enabled = remote_debugging_enabled
        self.remote_debugging_version = remote_debugging_version
        self.http_logging_enabled = http_logging_enabled
        self.logs_directory_size_limit = logs_directory_size_limit
        self.detailed_error_logging_enabled = detailed_error_logging_enabled
        self.publishing_username = publishing_username
        self.app_settings = app_settings
        self.connection_strings = connection_strings
        self.machine_key = None
        self.handler_mappings = handler_mappings
        self.document_root = document_root
        self.scm_type = scm_type
        self.use32_bit_worker_process = use32_bit_worker_process
        self.web_sockets_enabled = web_sockets_enabled
        self.always_on = always_on
        self.java_version = java_version
        self.java_container = java_container
        self.java_container_version = java_container_version
        self.app_command_line = app_command_line
        self.managed_pipeline_mode = managed_pipeline_mode
        self.virtual_applications = virtual_applications
        self.load_balancing = load_balancing
        self.experiments = experiments
        self.limits = limits
        self.auto_heal_enabled = auto_heal_enabled
        self.auto_heal_rules = auto_heal_rules
        self.tracing_options = tracing_options
        self.vnet_name = vnet_name
        self.vnet_route_all_enabled = vnet_route_all_enabled
        self.vnet_private_ports_count = vnet_private_ports_count
        self.public_network_access = public_network_access
        self.cors = cors
        self.push = push
        self.api_definition = api_definition
        self.api_management_config = api_management_config
        self.auto_swap_slot_name = auto_swap_slot_name
        self.local_my_sql_enabled = local_my_sql_enabled
        self.managed_service_identity_id = managed_service_identity_id
        self.x_managed_service_identity_id = x_managed_service_identity_id
        self.key_vault_reference_identity = key_vault_reference_identity
        self.ip_security_restrictions = ip_security_restrictions
        self.scm_ip_security_restrictions = scm_ip_security_restrictions
        self.scm_ip_security_restrictions_use_main = scm_ip_security_restrictions_use_main
        self.http20_enabled = http20_enabled
        self.min_tls_version = min_tls_version
        self.scm_min_tls_version = scm_min_tls_version
        self.ftps_state = ftps_state
        self.pre_warmed_instance_count = pre_warmed_instance_count
        self.function_app_scale_limit = function_app_scale_limit
        self.health_check_path = health_check_path
        self.functions_runtime_scale_monitoring_enabled = functions_runtime_scale_monitoring_enabled
        self.website_time_zone = website_time_zone
        self.minimum_elastic_instance_count = minimum_elastic_instance_count
        self.azure_storage_accounts = azure_storage_accounts
        self.http20_proxy_flag = http20_proxy_flag
        self.site_port = site_port
        self.antivirus_scan_enabled = antivirus_scan_enabled


class SiteLimits(Model):
    """Metric limits set on an app.

    :param max_percentage_cpu: Maximum allowed CPU usage percentage.
    :type max_percentage_cpu: float
    :param max_memory_in_mb: Maximum allowed memory usage in MB.
    :type max_memory_in_mb: long
    :param max_disk_size_in_mb: Maximum allowed disk size usage in MB.
    :type max_disk_size_in_mb: long
    """

    _attribute_map = {
        'max_percentage_cpu': {'key': 'maxPercentageCpu', 'type': 'float'},
        'max_memory_in_mb': {'key': 'maxMemoryInMb', 'type': 'long'},
        'max_disk_size_in_mb': {'key': 'maxDiskSizeInMb', 'type': 'long'},
    }

    def __init__(self, *, max_percentage_cpu: float=None, max_memory_in_mb: int=None, max_disk_size_in_mb: int=None, **kwargs) -> None:
        super(SiteLimits, self).__init__(**kwargs)
        self.max_percentage_cpu = max_percentage_cpu
        self.max_memory_in_mb = max_memory_in_mb
        self.max_disk_size_in_mb = max_disk_size_in_mb


class SiteMachineKey(Model):
    """MachineKey of an app.

    :param validation: MachineKey validation.
    :type validation: str
    :param validation_key: Validation key.
    :type validation_key: str
    :param decryption: Algorithm used for decryption.
    :type decryption: str
    :param decryption_key: Decryption key.
    :type decryption_key: str
    """

    _attribute_map = {
        'validation': {'key': 'validation', 'type': 'str'},
        'validation_key': {'key': 'validationKey', 'type': 'str'},
        'decryption': {'key': 'decryption', 'type': 'str'},
        'decryption_key': {'key': 'decryptionKey', 'type': 'str'},
    }

    def __init__(self, *, validation: str=None, validation_key: str=None, decryption: str=None, decryption_key: str=None, **kwargs) -> None:
        super(SiteMachineKey, self).__init__(**kwargs)
        self.validation = validation
        self.validation_key = validation_key
        self.decryption = decryption
        self.decryption_key = decryption_key


class SiteSecretInfoConfig(Model):
    """SiteSecretInfoConfig.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param name:
    :type name: str
    :param type: Possible values include: 'String', 'KeyVault'
    :type type: str or ~azure.mgmt.web.v2021_02_01.models.SiteSecretType
    :ivar status: Possible values include: 'Initialized', 'Resolved',
     'InvalidSyntax', 'MSINotEnabled', 'VaultNotFound', 'SecretNotFound',
     'SecretVersionNotFound', 'AccessToKeyVaultDenied', 'OtherReasons',
     'FetchTimedOut', 'UnauthorizedClient'
    :vartype status: str or ~azure.mgmt.web.v2021_02_01.models.ResolveStatus
    :param vault_name:
    :type vault_name: str
    :param secret_name:
    :type secret_name: str
    :param secret_version:
    :type secret_version: str
    :param value:
    :type value: str
    :param secret_uri:
    :type secret_uri: str
    """

    _validation = {
        'status': {'readonly': True},
    }

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'type': {'key': 'type', 'type': 'SiteSecretType'},
        'status': {'key': 'status', 'type': 'ResolveStatus'},
        'vault_name': {'key': 'vaultName', 'type': 'str'},
        'secret_name': {'key': 'secretName', 'type': 'str'},
        'secret_version': {'key': 'secretVersion', 'type': 'str'},
        'value': {'key': 'value', 'type': 'str'},
        'secret_uri': {'key': 'secretUri', 'type': 'str'},
    }

    def __init__(self, *, name: str=None, type=None, vault_name: str=None, secret_name: str=None, secret_version: str=None, value: str=None, secret_uri: str=None, **kwargs) -> None:
        super(SiteSecretInfoConfig, self).__init__(**kwargs)
        self.name = name
        self.type = type
        self.status = None
        self.vault_name = vault_name
        self.secret_name = secret_name
        self.secret_version = secret_version
        self.value = value
        self.secret_uri = secret_uri


class SkuDescription(Model):
    """Description of a SKU for a scalable resource.

    :param name: Name of the resource SKU.
    :type name: str
    :param tier: Service tier of the resource SKU.
    :type tier: str
    :param size: Size specifier of the resource SKU.
    :type size: str
    :param family: Family code of the resource SKU.
    :type family: str
    :param capacity: Current number of instances assigned to the resource.
    :type capacity: int
    :param locations: Locations of the SKU.
    :type locations: list[str]
    :param capabilities: Capabilities of the SKU, e.g., is traffic manager
     enabled?
    :type capabilities: list[~azure.mgmt.web.v2021_02_01.models.Capability]
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'tier': {'key': 'tier', 'type': 'str'},
        'size': {'key': 'size', 'type': 'str'},
        'family': {'key': 'family', 'type': 'str'},
        'capacity': {'key': 'capacity', 'type': 'int'},
        'locations': {'key': 'locations', 'type': '[str]'},
        'capabilities': {'key': 'capabilities', 'type': '[Capability]'},
    }

    def __init__(self, *, name: str=None, tier: str=None, size: str=None, family: str=None, capacity: int=None, locations=None, capabilities=None, **kwargs) -> None:
        super(SkuDescription, self).__init__(**kwargs)
        self.name = name
        self.tier = tier
        self.size = size
        self.family = family
        self.capacity = capacity
        self.locations = locations
        self.capabilities = capabilities


class SlotSwapStatus(Model):
    """The status of the last successful slot swap operation.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar timestamp_utc: The time the last successful slot swap completed.
    :vartype timestamp_utc: datetime
    :ivar source_slot_name: The source slot of the last swap operation.
    :vartype source_slot_name: str
    :ivar destination_slot_name: The destination slot of the last swap
     operation.
    :vartype destination_slot_name: str
    """

    _validation = {
        'timestamp_utc': {'readonly': True},
        'source_slot_name': {'readonly': True},
        'destination_slot_name': {'readonly': True},
    }

    _attribute_map = {
        'timestamp_utc': {'key': 'timestampUtc', 'type': 'iso-8601'},
        'source_slot_name': {'key': 'sourceSlotName', 'type': 'str'},
        'destination_slot_name': {'key': 'destinationSlotName', 'type': 'str'},
    }

    def __init__(self, **kwargs) -> None:
        super(SlotSwapStatus, self).__init__(**kwargs)
        self.timestamp_utc = None
        self.source_slot_name = None
        self.destination_slot_name = None


class SlowRequestsBasedTrigger(Model):
    """Trigger based on request execution time.

    :param time_taken: Time taken.
    :type time_taken: str
    :param path: Request Path.
    :type path: str
    :param count: Request Count.
    :type count: int
    :param time_interval: Time interval.
    :type time_interval: str
    """

    _attribute_map = {
        'time_taken': {'key': 'timeTaken', 'type': 'str'},
        'path': {'key': 'path', 'type': 'str'},
        'count': {'key': 'count', 'type': 'int'},
        'time_interval': {'key': 'timeInterval', 'type': 'str'},
    }

    def __init__(self, *, time_taken: str=None, path: str=None, count: int=None, time_interval: str=None, **kwargs) -> None:
        super(SlowRequestsBasedTrigger, self).__init__(**kwargs)
        self.time_taken = time_taken
        self.path = path
        self.count = count
        self.time_interval = time_interval


class Snapshot(ProxyOnlyResource):
    """A snapshot of an app.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar id: Resource Id.
    :vartype id: str
    :ivar name: Resource Name.
    :vartype name: str
    :param kind: Kind of resource.
    :type kind: str
    :ivar type: Resource type.
    :vartype type: str
    :ivar time: The time the snapshot was taken.
    :vartype time: str
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
        'time': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'kind': {'key': 'kind', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'time': {'key': 'properties.time', 'type': 'str'},
    }

    def __init__(self, *, kind: str=None, **kwargs) -> None:
        super(Snapshot, self).__init__(kind=kind, **kwargs)
        self.time = None


class Status(Model):
    """Identify the status of the most severe insight generated by the detector.

    :param message: Descriptive message.
    :type message: str
    :param status_id: Level of the most severe insight generated by the
     detector. Possible values include: 'Critical', 'Warning', 'Info',
     'Success', 'None'
    :type status_id: str or ~azure.mgmt.web.v2021_02_01.models.InsightStatus
    """

    _attribute_map = {
        'message': {'key': 'message', 'type': 'str'},
        'status_id': {'key': 'statusId', 'type': 'InsightStatus'},
    }

    def __init__(self, *, message: str=None, status_id=None, **kwargs) -> None:
        super(Status, self).__init__(**kwargs)
        self.message = message
        self.status_id = status_id


class StatusCodesBasedTrigger(Model):
    """Trigger based on status code.

    :param status: HTTP status code.
    :type status: int
    :param sub_status: Request Sub Status.
    :type sub_status: int
    :param win32_status: Win32 error code.
    :type win32_status: int
    :param count: Request Count.
    :type count: int
    :param time_interval: Time interval.
    :type time_interval: str
    :param path: Request Path
    :type path: str
    """

    _attribute_map = {
        'status': {'key': 'status', 'type': 'int'},
        'sub_status': {'key': 'subStatus', 'type': 'int'},
        'win32_status': {'key': 'win32Status', 'type': 'int'},
        'count': {'key': 'count', 'type': 'int'},
        'time_interval': {'key': 'timeInterval', 'type': 'str'},
        'path': {'key': 'path', 'type': 'str'},
    }

    def __init__(self, *, status: int=None, sub_status: int=None, win32_status: int=None, count: int=None, time_interval: str=None, path: str=None, **kwargs) -> None:
        super(StatusCodesBasedTrigger, self).__init__(**kwargs)
        self.status = status
        self.sub_status = sub_status
        self.win32_status = win32_status
        self.count = count
        self.time_interval = time_interval
        self.path = path


class StatusCodesRangeBasedTrigger(Model):
    """Trigger based on range of status codes.

    :param status_codes: HTTP status code.
    :type status_codes: str
    :param path:
    :type path: str
    :param count: Request Count.
    :type count: int
    :param time_interval: Time interval.
    :type time_interval: str
    """

    _attribute_map = {
        'status_codes': {'key': 'statusCodes', 'type': 'str'},
        'path': {'key': 'path', 'type': 'str'},
        'count': {'key': 'count', 'type': 'int'},
        'time_interval': {'key': 'timeInterval', 'type': 'str'},
    }

    def __init__(self, *, status_codes: str=None, path: str=None, count: int=None, time_interval: str=None, **kwargs) -> None:
        super(StatusCodesRangeBasedTrigger, self).__init__(**kwargs)
        self.status_codes = status_codes
        self.path = path
        self.count = count
        self.time_interval = time_interval


class StringDictionary(ProxyOnlyResource):
    """String dictionary resource.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar id: Resource Id.
    :vartype id: str
    :ivar name: Resource Name.
    :vartype name: str
    :param kind: Kind of resource.
    :type kind: str
    :ivar type: Resource type.
    :vartype type: str
    :param properties: Settings.
    :type properties: dict[str, str]
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'kind': {'key': 'kind', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'properties': {'key': 'properties', 'type': '{str}'},
    }

    def __init__(self, *, kind: str=None, properties=None, **kwargs) -> None:
        super(StringDictionary, self).__init__(kind=kind, **kwargs)
        self.properties = properties


class SupportTopic(Model):
    """Defines a unique Support Topic.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar id: Support Topic Id
    :vartype id: str
    :ivar pes_id: Unique resource Id
    :vartype pes_id: str
    """

    _validation = {
        'id': {'readonly': True},
        'pes_id': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'pes_id': {'key': 'pesId', 'type': 'str'},
    }

    def __init__(self, **kwargs) -> None:
        super(SupportTopic, self).__init__(**kwargs)
        self.id = None
        self.pes_id = None


class User(ProxyOnlyResource):
    """User credentials used for publishing activity.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    All required parameters must be populated in order to send to Azure.

    :ivar id: Resource Id.
    :vartype id: str
    :ivar name: Resource Name.
    :vartype name: str
    :param kind: Kind of resource.
    :type kind: str
    :ivar type: Resource type.
    :vartype type: str
    :param publishing_user_name: Required. Username used for publishing.
    :type publishing_user_name: str
    :param publishing_password: Password used for publishing.
    :type publishing_password: str
    :param publishing_password_hash: Password hash used for publishing.
    :type publishing_password_hash: str
    :param publishing_password_hash_salt: Password hash salt used for
     publishing.
    :type publishing_password_hash_salt: str
    :param scm_uri: Url of SCM site.
    :type scm_uri: str
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
        'publishing_user_name': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'kind': {'key': 'kind', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'publishing_user_name': {'key': 'properties.publishingUserName', 'type': 'str'},
        'publishing_password': {'key': 'properties.publishingPassword', 'type': 'str'},
        'publishing_password_hash': {'key': 'properties.publishingPasswordHash', 'type': 'str'},
        'publishing_password_hash_salt': {'key': 'properties.publishingPasswordHashSalt', 'type': 'str'},
        'scm_uri': {'key': 'properties.scmUri', 'type': 'str'},
    }

    def __init__(self, *, publishing_user_name: str, kind: str=None, publishing_password: str=None, publishing_password_hash: str=None, publishing_password_hash_salt: str=None, scm_uri: str=None, **kwargs) -> None:
        super(User, self).__init__(kind=kind, **kwargs)
        self.publishing_user_name = publishing_user_name
        self.publishing_password = publishing_password
        self.publishing_password_hash = publishing_password_hash
        self.publishing_password_hash_salt = publishing_password_hash_salt
        self.scm_uri = scm_uri


class UserAssignedIdentity(Model):
    """User Assigned identity.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar principal_id: Principal Id of user assigned identity
    :vartype principal_id: str
    :ivar client_id: Client Id of user assigned identity
    :vartype client_id: str
    """

    _validation = {
        'principal_id': {'readonly': True},
        'client_id': {'readonly': True},
    }

    _attribute_map = {
        'principal_id': {'key': 'principalId', 'type': 'str'},
        'client_id': {'key': 'clientId', 'type': 'str'},
    }

    def __init__(self, **kwargs) -> None:
        super(UserAssignedIdentity, self).__init__(**kwargs)
        self.principal_id = None
        self.client_id = None


class VirtualApplication(Model):
    """Virtual application in an app.

    :param virtual_path: Virtual path.
    :type virtual_path: str
    :param physical_path: Physical path.
    :type physical_path: str
    :param preload_enabled: <code>true</code> if preloading is enabled;
     otherwise, <code>false</code>.
    :type preload_enabled: bool
    :param virtual_directories: Virtual directories for virtual application.
    :type virtual_directories:
     list[~azure.mgmt.web.v2021_02_01.models.VirtualDirectory]
    """

    _attribute_map = {
        'virtual_path': {'key': 'virtualPath', 'type': 'str'},
        'physical_path': {'key': 'physicalPath', 'type': 'str'},
        'preload_enabled': {'key': 'preloadEnabled', 'type': 'bool'},
        'virtual_directories': {'key': 'virtualDirectories', 'type': '[VirtualDirectory]'},
    }

    def __init__(self, *, virtual_path: str=None, physical_path: str=None, preload_enabled: bool=None, virtual_directories=None, **kwargs) -> None:
        super(VirtualApplication, self).__init__(**kwargs)
        self.virtual_path = virtual_path
        self.physical_path = physical_path
        self.preload_enabled = preload_enabled
        self.virtual_directories = virtual_directories


class VirtualDirectory(Model):
    """Directory for virtual application.

    :param virtual_path: Path to virtual application.
    :type virtual_path: str
    :param physical_path: Physical path.
    :type physical_path: str
    """

    _attribute_map = {
        'virtual_path': {'key': 'virtualPath', 'type': 'str'},
        'physical_path': {'key': 'physicalPath', 'type': 'str'},
    }

    def __init__(self, *, virtual_path: str=None, physical_path: str=None, **kwargs) -> None:
        super(VirtualDirectory, self).__init__(**kwargs)
        self.virtual_path = virtual_path
        self.physical_path = physical_path


class VirtualNetworkProfile(Model):
    """Specification for using a Virtual Network.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    All required parameters must be populated in order to send to Azure.

    :param id: Required. Resource id of the Virtual Network.
    :type id: str
    :ivar name: Name of the Virtual Network (read-only).
    :vartype name: str
    :ivar type: Resource type of the Virtual Network (read-only).
    :vartype type: str
    :param subnet: Subnet within the Virtual Network.
    :type subnet: str
    """

    _validation = {
        'id': {'required': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'subnet': {'key': 'subnet', 'type': 'str'},
    }

    def __init__(self, *, id: str, subnet: str=None, **kwargs) -> None:
        super(VirtualNetworkProfile, self).__init__(**kwargs)
        self.id = id
        self.name = None
        self.type = None
        self.subnet = subnet


class VnetGateway(ProxyOnlyResource):
    """The Virtual Network gateway contract. This is used to give the Virtual
    Network gateway access to the VPN package.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    All required parameters must be populated in order to send to Azure.

    :ivar id: Resource Id.
    :vartype id: str
    :ivar name: Resource Name.
    :vartype name: str
    :param kind: Kind of resource.
    :type kind: str
    :ivar type: Resource type.
    :vartype type: str
    :param vnet_name: The Virtual Network name.
    :type vnet_name: str
    :param vpn_package_uri: Required. The URI where the VPN package can be
     downloaded.
    :type vpn_package_uri: str
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
        'vpn_package_uri': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'kind': {'key': 'kind', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'vnet_name': {'key': 'properties.vnetName', 'type': 'str'},
        'vpn_package_uri': {'key': 'properties.vpnPackageUri', 'type': 'str'},
    }

    def __init__(self, *, vpn_package_uri: str, kind: str=None, vnet_name: str=None, **kwargs) -> None:
        super(VnetGateway, self).__init__(kind=kind, **kwargs)
        self.vnet_name = vnet_name
        self.vpn_package_uri = vpn_package_uri


class VnetInfoResource(ProxyOnlyResource):
    """Virtual Network information ARM resource.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar id: Resource Id.
    :vartype id: str
    :ivar name: Resource Name.
    :vartype name: str
    :param kind: Kind of resource.
    :type kind: str
    :ivar type: Resource type.
    :vartype type: str
    :param vnet_resource_id: The Virtual Network's resource ID.
    :type vnet_resource_id: str
    :ivar cert_thumbprint: The client certificate thumbprint.
    :vartype cert_thumbprint: str
    :param cert_blob: A certificate file (.cer) blob containing the public key
     of the private key used to authenticate a
     Point-To-Site VPN connection.
    :type cert_blob: str
    :ivar routes: The routes that this Virtual Network connection uses.
    :vartype routes: list[~azure.mgmt.web.v2021_02_01.models.VnetRoute]
    :ivar resync_required: <code>true</code> if a resync is required;
     otherwise, <code>false</code>.
    :vartype resync_required: bool
    :param dns_servers: DNS servers to be used by this Virtual Network. This
     should be a comma-separated list of IP addresses.
    :type dns_servers: str
    :param is_swift: Flag that is used to denote if this is VNET injection
    :type is_swift: bool
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
        'cert_thumbprint': {'readonly': True},
        'routes': {'readonly': True},
        'resync_required': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'kind': {'key': 'kind', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'vnet_resource_id': {'key': 'properties.vnetResourceId', 'type': 'str'},
        'cert_thumbprint': {'key': 'properties.certThumbprint', 'type': 'str'},
        'cert_blob': {'key': 'properties.certBlob', 'type': 'str'},
        'routes': {'key': 'properties.routes', 'type': '[VnetRoute]'},
        'resync_required': {'key': 'properties.resyncRequired', 'type': 'bool'},
        'dns_servers': {'key': 'properties.dnsServers', 'type': 'str'},
        'is_swift': {'key': 'properties.isSwift', 'type': 'bool'},
    }

    def __init__(self, *, kind: str=None, vnet_resource_id: str=None, cert_blob: str=None, dns_servers: str=None, is_swift: bool=None, **kwargs) -> None:
        super(VnetInfoResource, self).__init__(kind=kind, **kwargs)
        self.vnet_resource_id = vnet_resource_id
        self.cert_thumbprint = None
        self.cert_blob = cert_blob
        self.routes = None
        self.resync_required = None
        self.dns_servers = dns_servers
        self.is_swift = is_swift


class VnetRoute(ProxyOnlyResource):
    """Virtual Network route contract used to pass routing information for a
    Virtual Network.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar id: Resource Id.
    :vartype id: str
    :ivar name: Resource Name.
    :vartype name: str
    :param kind: Kind of resource.
    :type kind: str
    :ivar type: Resource type.
    :vartype type: str
    :param start_address: The starting address for this route. This may also
     include a CIDR notation, in which case the end address must not be
     specified.
    :type start_address: str
    :param end_address: The ending address for this route. If the start
     address is specified in CIDR notation, this must be omitted.
    :type end_address: str
    :param route_type: The type of route this is:
     DEFAULT - By default, every app has routes to the local address ranges
     specified by RFC1918
     INHERITED - Routes inherited from the real Virtual Network routes
     STATIC - Static route set on the app only
     These values will be used for syncing an app's routes with those from a
     Virtual Network. Possible values include: 'DEFAULT', 'INHERITED', 'STATIC'
    :type route_type: str or ~azure.mgmt.web.v2021_02_01.models.RouteType
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'kind': {'key': 'kind', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'start_address': {'key': 'properties.startAddress', 'type': 'str'},
        'end_address': {'key': 'properties.endAddress', 'type': 'str'},
        'route_type': {'key': 'properties.routeType', 'type': 'str'},
    }

    def __init__(self, *, kind: str=None, start_address: str=None, end_address: str=None, route_type=None, **kwargs) -> None:
        super(VnetRoute, self).__init__(kind=kind, **kwargs)
        self.start_address = start_address
        self.end_address = end_address
        self.route_type = route_type


class WebAppCollection(Model):
    """Collection of App Service apps.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    All required parameters must be populated in order to send to Azure.

    :param value: Required. Collection of resources.
    :type value: list[~azure.mgmt.web.v2021_02_01.models.Site]
    :ivar next_link: Link to next page of resources.
    :vartype next_link: str
    """

    _validation = {
        'value': {'required': True},
        'next_link': {'readonly': True},
    }

    _attribute_map = {
        'value': {'key': 'value', 'type': '[Site]'},
        'next_link': {'key': 'nextLink', 'type': 'str'},
    }

    def __init__(self, *, value, **kwargs) -> None:
        super(WebAppCollection, self).__init__(**kwargs)
        self.value = value
        self.next_link = None


class WorkerApp(Resource):
    """Worker App.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    All required parameters must be populated in order to send to Azure.

    :ivar id: Resource Id.
    :vartype id: str
    :ivar name: Resource Name.
    :vartype name: str
    :param kind: Kind of resource.
    :type kind: str
    :param location: Required. Resource Location.
    :type location: str
    :ivar type: Resource type.
    :vartype type: str
    :param tags: Resource tags.
    :type tags: dict[str, str]
    :ivar provisioning_state: Provisioning state of the Worker App. Possible
     values include: 'InProgress', 'Succeeded', 'Failed', 'Canceled'
    :vartype provisioning_state: str or
     ~azure.mgmt.web.v2021_02_01.models.WorkerAppProvisioningState
    :param kube_environment_id: Resource ID of the Worker App's
     KubeEnvironment.
    :type kube_environment_id: str
    :ivar latest_revision_name: Name of the latest revision of the Worker App.
    :vartype latest_revision_name: str
    :ivar latest_revision_fqdn: Fully Qualified Domain Name of the latest
     revision of the Worker App.
    :vartype latest_revision_fqdn: str
    :param configuration: Non versioned Worker App configuration properties.
    :type configuration:
     ~azure.mgmt.web.v2021_02_01.models.WorkerAppConfiguration
    :param template: Worker App versioned application definition.
    :type template: ~azure.mgmt.web.v2021_02_01.models.WorkerAppTemplate
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'location': {'required': True},
        'type': {'readonly': True},
        'provisioning_state': {'readonly': True},
        'latest_revision_name': {'readonly': True},
        'latest_revision_fqdn': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'kind': {'key': 'kind', 'type': 'str'},
        'location': {'key': 'location', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'tags': {'key': 'tags', 'type': '{str}'},
        'provisioning_state': {'key': 'properties.provisioningState', 'type': 'WorkerAppProvisioningState'},
        'kube_environment_id': {'key': 'properties.kubeEnvironmentId', 'type': 'str'},
        'latest_revision_name': {'key': 'properties.latestRevisionName', 'type': 'str'},
        'latest_revision_fqdn': {'key': 'properties.latestRevisionFqdn', 'type': 'str'},
        'configuration': {'key': 'properties.configuration', 'type': 'WorkerAppConfiguration'},
        'template': {'key': 'properties.template', 'type': 'WorkerAppTemplate'},
    }

    def __init__(self, *, location: str, kind: str=None, tags=None, kube_environment_id: str=None, configuration=None, template=None, **kwargs) -> None:
        super(WorkerApp, self).__init__(kind=kind, location=location, tags=tags, **kwargs)
        self.provisioning_state = None
        self.kube_environment_id = kube_environment_id
        self.latest_revision_name = None
        self.latest_revision_fqdn = None
        self.configuration = configuration
        self.template = template


class WorkerAppConfiguration(Model):
    """Non versioned Worker App configuration properties that define the mutable
    settings of a worker app.

    :param secrets: Collection of secrets used by a worker app
    :type secrets: list[~azure.mgmt.web.v2021_02_01.models.WorkerAppSecret]
    :param active_revisions_mode: ActiveRevisionsMode controls how active
     revisions are handled for the worker app:
     <list><item>Multiple: multiple revisions can be active. If no value if
     provided, this is the default</item><item>Single: Only one revision can be
     active at a time. Revision weights can not be used in this
     mode</item></list>. Possible values include: 'multiple', 'single'
    :type active_revisions_mode: str or
     ~azure.mgmt.web.v2021_02_01.models.WorkerAppActiveRevisionsMode
    :param ingress: Ingress configurations.
    :type ingress: ~azure.mgmt.web.v2021_02_01.models.WorkerAppIngress
    :param registries: Collection of private container registry credentials
     for containers used by the worker app
    :type registries:
     list[~azure.mgmt.web.v2021_02_01.models.WorkerAppRegistryCredentials]
    """

    _attribute_map = {
        'secrets': {'key': 'secrets', 'type': '[WorkerAppSecret]'},
        'active_revisions_mode': {'key': 'activeRevisionsMode', 'type': 'WorkerAppActiveRevisionsMode'},
        'ingress': {'key': 'ingress', 'type': 'WorkerAppIngress'},
        'registries': {'key': 'registries', 'type': '[WorkerAppRegistryCredentials]'},
    }

    def __init__(self, *, secrets=None, active_revisions_mode=None, ingress=None, registries=None, **kwargs) -> None:
        super(WorkerAppConfiguration, self).__init__(**kwargs)
        self.secrets = secrets
        self.active_revisions_mode = active_revisions_mode
        self.ingress = ingress
        self.registries = registries


class WorkerAppContainer(Model):
    """Worker App container definition.

    :param image: Container image tag.
    :type image: str
    :param name: Custom container name.
    :type name: str
    :param command: Container start command.
    :type command: list[str]
    :param args: Container start command arguments.
    :type args: list[str]
    :param env: Container environment variables.
    :type env:
     list[~azure.mgmt.web.v2021_02_01.models.WorkerAppEnvironmentVar]
    :param resources: Container resource requirements.
    :type resources:
     ~azure.mgmt.web.v2021_02_01.models.WorkerAppContainerResources
    """

    _attribute_map = {
        'image': {'key': 'image', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'command': {'key': 'command', 'type': '[str]'},
        'args': {'key': 'args', 'type': '[str]'},
        'env': {'key': 'env', 'type': '[WorkerAppEnvironmentVar]'},
        'resources': {'key': 'resources', 'type': 'WorkerAppContainerResources'},
    }

    def __init__(self, *, image: str=None, name: str=None, command=None, args=None, env=None, resources=None, **kwargs) -> None:
        super(WorkerAppContainer, self).__init__(**kwargs)
        self.image = image
        self.name = name
        self.command = command
        self.args = args
        self.env = env
        self.resources = resources


class WorkerAppContainerResources(Model):
    """Worker App container resource requirements.

    :param cpu: Required CPU in cores, e.g. 0.5
    :type cpu: float
    :param memory: Required memory, e.g. "250Mb"
    :type memory: str
    """

    _attribute_map = {
        'cpu': {'key': 'cpu', 'type': 'float'},
        'memory': {'key': 'memory', 'type': 'str'},
    }

    def __init__(self, *, cpu: float=None, memory: str=None, **kwargs) -> None:
        super(WorkerAppContainerResources, self).__init__(**kwargs)
        self.cpu = cpu
        self.memory = memory


class WorkerAppCustomScaleRule(Model):
    """Worker App container Custom scaling rule.

    :param type: Type of the custom scale rule
     eg: azure-servicebus, redis etc.
    :type type: str
    :param metadata: Metadata properties to describe custom scale rule.
    :type metadata: dict[str, str]
    :param auth: Authentication secrets for the custom scale rule.
    :type auth:
     list[~azure.mgmt.web.v2021_02_01.models.WorkerAppScaleRuleAuth]
    """

    _attribute_map = {
        'type': {'key': 'type', 'type': 'str'},
        'metadata': {'key': 'metadata', 'type': '{str}'},
        'auth': {'key': 'auth', 'type': '[WorkerAppScaleRuleAuth]'},
    }

    def __init__(self, *, type: str=None, metadata=None, auth=None, **kwargs) -> None:
        super(WorkerAppCustomScaleRule, self).__init__(**kwargs)
        self.type = type
        self.metadata = metadata
        self.auth = auth


class WorkerAppDapr(Model):
    """Worker App Dapr configuration.

    :param enabled: Boolean indicating if the Dapr side car is enabled
    :type enabled: bool
    :param app_id: Dapr application identifier
    :type app_id: str
    :param app_port: Port on which the Dapr side car
    :type app_port: int
    :param components: Collection of Dapr components
    :type components:
     list[~azure.mgmt.web.v2021_02_01.models.WorkerAppDaprComponent]
    """

    _attribute_map = {
        'enabled': {'key': 'enabled', 'type': 'bool'},
        'app_id': {'key': 'appId', 'type': 'str'},
        'app_port': {'key': 'appPort', 'type': 'int'},
        'components': {'key': 'components', 'type': '[WorkerAppDaprComponent]'},
    }

    def __init__(self, *, enabled: bool=None, app_id: str=None, app_port: int=None, components=None, **kwargs) -> None:
        super(WorkerAppDapr, self).__init__(**kwargs)
        self.enabled = enabled
        self.app_id = app_id
        self.app_port = app_port
        self.components = components


class WorkerAppDaprComponent(Model):
    """Dapr component configuration.

    :param name: Component name
    :type name: str
    :param type: Component type
    :type type: str
    :param version: Component version
    :type version: str
    :param metadata: Component metadata
    :type metadata:
     list[~azure.mgmt.web.v2021_02_01.models.WorkerAppDaprMetadata]
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'version': {'key': 'version', 'type': 'str'},
        'metadata': {'key': 'metadata', 'type': '[WorkerAppDaprMetadata]'},
    }

    def __init__(self, *, name: str=None, type: str=None, version: str=None, metadata=None, **kwargs) -> None:
        super(WorkerAppDaprComponent, self).__init__(**kwargs)
        self.name = name
        self.type = type
        self.version = version
        self.metadata = metadata


class WorkerAppDaprMetadata(Model):
    """Worker App Dapr component metadata.

    :param name: Metadata property name.
    :type name: str
    :param value: Metadata property value.
    :type value: str
    :param secret_ref: Name of the Worker App secret from which to pull the
     metadata property value.
    :type secret_ref: str
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'value': {'key': 'value', 'type': 'str'},
        'secret_ref': {'key': 'secretRef', 'type': 'str'},
    }

    def __init__(self, *, name: str=None, value: str=None, secret_ref: str=None, **kwargs) -> None:
        super(WorkerAppDaprMetadata, self).__init__(**kwargs)
        self.name = name
        self.value = value
        self.secret_ref = secret_ref


class WorkerAppEnvironmentVar(Model):
    """Worker App container environment variable.

    :param name: Environment variable name.
    :type name: str
    :param value: Non-secret environment variable value.
    :type value: str
    :param secret_ref: Name of the Worker App secret from which to pull the
     environment variable value.
    :type secret_ref: str
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'value': {'key': 'value', 'type': 'str'},
        'secret_ref': {'key': 'secretRef', 'type': 'str'},
    }

    def __init__(self, *, name: str=None, value: str=None, secret_ref: str=None, **kwargs) -> None:
        super(WorkerAppEnvironmentVar, self).__init__(**kwargs)
        self.name = name
        self.value = value
        self.secret_ref = secret_ref


class WorkerAppHttpScaleRule(Model):
    """Worker App container Custom scaling rule.

    :param metadata: Metadata properties to describe http scale rule.
    :type metadata: dict[str, str]
    :param auth: Authentication secrets for the custom scale rule.
    :type auth:
     list[~azure.mgmt.web.v2021_02_01.models.WorkerAppScaleRuleAuth]
    """

    _attribute_map = {
        'metadata': {'key': 'metadata', 'type': '{str}'},
        'auth': {'key': 'auth', 'type': '[WorkerAppScaleRuleAuth]'},
    }

    def __init__(self, *, metadata=None, auth=None, **kwargs) -> None:
        super(WorkerAppHttpScaleRule, self).__init__(**kwargs)
        self.metadata = metadata
        self.auth = auth


class WorkerAppIngress(Model):
    """Worker App Ingress configuration.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar fqdn: Hostname.
    :vartype fqdn: str
    :param external: Bool indicating if app exposes an external http endpoint.
     Default value: False .
    :type external: bool
    :param target_port: Target Port in containers for traffic from ingress
    :type target_port: int
    :param transport: Ingress transport protocol. Possible values include:
     'auto', 'http', 'http2'
    :type transport: str or
     ~azure.mgmt.web.v2021_02_01.models.WorkerAppIngressTransportMethod
    :param traffic:
    :type traffic:
     list[~azure.mgmt.web.v2021_02_01.models.WorkerAppTrafficWeight]
    :param allow_insecure: Bool indicating if HTTP connections to workerapp is
     allowed. If set to false HTTP connections are automatically redirected to
     HTTPS connections
    :type allow_insecure: bool
    """

    _validation = {
        'fqdn': {'readonly': True},
    }

    _attribute_map = {
        'fqdn': {'key': 'fqdn', 'type': 'str'},
        'external': {'key': 'external', 'type': 'bool'},
        'target_port': {'key': 'targetPort', 'type': 'int'},
        'transport': {'key': 'transport', 'type': 'WorkerAppIngressTransportMethod'},
        'traffic': {'key': 'traffic', 'type': '[WorkerAppTrafficWeight]'},
        'allow_insecure': {'key': 'allowInsecure', 'type': 'bool'},
    }

    def __init__(self, *, external: bool=False, target_port: int=None, transport=None, traffic=None, allow_insecure: bool=None, **kwargs) -> None:
        super(WorkerAppIngress, self).__init__(**kwargs)
        self.fqdn = None
        self.external = external
        self.target_port = target_port
        self.transport = transport
        self.traffic = traffic
        self.allow_insecure = allow_insecure


class WorkerAppQueueScaleRule(Model):
    """Worker App container Azure Queue based scaling rule.

    :param queue_name: Queue name.
    :type queue_name: str
    :param queue_length: Queue length.
    :type queue_length: int
    :param auth: Authentication secrets for the queue scale rule.
    :type auth:
     list[~azure.mgmt.web.v2021_02_01.models.WorkerAppScaleRuleAuth]
    """

    _attribute_map = {
        'queue_name': {'key': 'queueName', 'type': 'str'},
        'queue_length': {'key': 'queueLength', 'type': 'int'},
        'auth': {'key': 'auth', 'type': '[WorkerAppScaleRuleAuth]'},
    }

    def __init__(self, *, queue_name: str=None, queue_length: int=None, auth=None, **kwargs) -> None:
        super(WorkerAppQueueScaleRule, self).__init__(**kwargs)
        self.queue_name = queue_name
        self.queue_length = queue_length
        self.auth = auth


class WorkerAppRegistryCredentials(Model):
    """Worker App Private Registry.

    :param server: Container Registry Server
    :type server: str
    :param username: Container Registry Username
    :type username: str
    :param password_secret_ref: The name of the Secret that contains the
     registry login password
    :type password_secret_ref: str
    """

    _attribute_map = {
        'server': {'key': 'server', 'type': 'str'},
        'username': {'key': 'username', 'type': 'str'},
        'password_secret_ref': {'key': 'passwordSecretRef', 'type': 'str'},
    }

    def __init__(self, *, server: str=None, username: str=None, password_secret_ref: str=None, **kwargs) -> None:
        super(WorkerAppRegistryCredentials, self).__init__(**kwargs)
        self.server = server
        self.username = username
        self.password_secret_ref = password_secret_ref


class WorkerAppRevision(Resource):
    """Worker App Revision.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    All required parameters must be populated in order to send to Azure.

    :ivar id: Resource Id.
    :vartype id: str
    :ivar name: Resource Name.
    :vartype name: str
    :param kind: Kind of resource.
    :type kind: str
    :param location: Required. Resource Location.
    :type location: str
    :ivar type: Resource type.
    :vartype type: str
    :param tags: Resource tags.
    :type tags: dict[str, str]
    :ivar created_time: Timestamp describing when the revision was created
     by controller
    :vartype created_time: datetime
    :ivar fqdn: Fully qualified domain name of the revision
    :vartype fqdn: str
    :ivar template: Worker App Revision Template with all possible settings
     and the
     defaults if user did not provide them. The defaults are populated
     as they were at the creation time
    :vartype template: ~azure.mgmt.web.v2021_02_01.models.WorkerAppTemplate
    :ivar active: Boolean describing if the Revision is Active
    :vartype active: bool
    :ivar replicas: Number of pods currently running for this revision
    :vartype replicas: int
    :ivar traffic_weight: Traffic weight assigned to this revision
    :vartype traffic_weight: int
    :ivar provisioning_error: Optional Field - Platform Error Message
    :vartype provisioning_error: str
    :ivar health_state: Current health State of the revision. Possible values
     include: 'Healthy', 'Unhealthy', 'None'
    :vartype health_state: str or
     ~azure.mgmt.web.v2021_02_01.models.WorkerAppRevisionHealthState
    :ivar provisioning_state: Current provisioning State of the revision.
     Possible values include: 'Provisioning', 'Provisioned', 'Failed',
     'Deprovisioning', 'Deprovisioned'
    :vartype provisioning_state: str or
     ~azure.mgmt.web.v2021_02_01.models.WorkerAppRevisionProvisioningState
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'location': {'required': True},
        'type': {'readonly': True},
        'created_time': {'readonly': True},
        'fqdn': {'readonly': True},
        'template': {'readonly': True},
        'active': {'readonly': True},
        'replicas': {'readonly': True},
        'traffic_weight': {'readonly': True},
        'provisioning_error': {'readonly': True},
        'health_state': {'readonly': True},
        'provisioning_state': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'kind': {'key': 'kind', 'type': 'str'},
        'location': {'key': 'location', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'tags': {'key': 'tags', 'type': '{str}'},
        'created_time': {'key': 'properties.createdTime', 'type': 'iso-8601'},
        'fqdn': {'key': 'properties.fqdn', 'type': 'str'},
        'template': {'key': 'properties.template', 'type': 'WorkerAppTemplate'},
        'active': {'key': 'properties.active', 'type': 'bool'},
        'replicas': {'key': 'properties.replicas', 'type': 'int'},
        'traffic_weight': {'key': 'properties.trafficWeight', 'type': 'int'},
        'provisioning_error': {'key': 'properties.provisioningError', 'type': 'str'},
        'health_state': {'key': 'properties.healthState', 'type': 'WorkerAppRevisionHealthState'},
        'provisioning_state': {'key': 'properties.provisioningState', 'type': 'WorkerAppRevisionProvisioningState'},
    }

    def __init__(self, *, location: str, kind: str=None, tags=None, **kwargs) -> None:
        super(WorkerAppRevision, self).__init__(kind=kind, location=location, tags=tags, **kwargs)
        self.created_time = None
        self.fqdn = None
        self.template = None
        self.active = None
        self.replicas = None
        self.traffic_weight = None
        self.provisioning_error = None
        self.health_state = None
        self.provisioning_state = None


class WorkerAppScale(Model):
    """Worker App scaling configurations.

    :param min_replicas: Optional. Minimum number of container replicas.
    :type min_replicas: int
    :param max_replicas: Optional. Maximum number of container replicas.
     Defaults to 10 if not set.
    :type max_replicas: int
    :param rules: Scaling rules.
    :type rules: list[~azure.mgmt.web.v2021_02_01.models.WorkerAppScaleRule]
    """

    _attribute_map = {
        'min_replicas': {'key': 'minReplicas', 'type': 'int'},
        'max_replicas': {'key': 'maxReplicas', 'type': 'int'},
        'rules': {'key': 'rules', 'type': '[WorkerAppScaleRule]'},
    }

    def __init__(self, *, min_replicas: int=None, max_replicas: int=None, rules=None, **kwargs) -> None:
        super(WorkerAppScale, self).__init__(**kwargs)
        self.min_replicas = min_replicas
        self.max_replicas = max_replicas
        self.rules = rules


class WorkerAppScaleRule(Model):
    """Worker App container scaling rule.

    :param name: Scale Rule Name
    :type name: str
    :param azure_queue: Azure Queue based scaling.
    :type azure_queue:
     ~azure.mgmt.web.v2021_02_01.models.WorkerAppQueueScaleRule
    :param custom: Custom scale rule.
    :type custom: ~azure.mgmt.web.v2021_02_01.models.WorkerAppCustomScaleRule
    :param http: HTTP requests based scaling.
    :type http: ~azure.mgmt.web.v2021_02_01.models.WorkerAppHttpScaleRule
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'azure_queue': {'key': 'azureQueue', 'type': 'WorkerAppQueueScaleRule'},
        'custom': {'key': 'custom', 'type': 'WorkerAppCustomScaleRule'},
        'http': {'key': 'http', 'type': 'WorkerAppHttpScaleRule'},
    }

    def __init__(self, *, name: str=None, azure_queue=None, custom=None, http=None, **kwargs) -> None:
        super(WorkerAppScaleRule, self).__init__(**kwargs)
        self.name = name
        self.azure_queue = azure_queue
        self.custom = custom
        self.http = http


class WorkerAppScaleRuleAuth(Model):
    """Auth Secrets for Worker App Scale Rule.

    :param secret_ref: Name of the Worker App secret from which to pull the
     auth params.
    :type secret_ref: str
    :param trigger_parameter: Trigger Parameter that uses the secret
    :type trigger_parameter: str
    """

    _attribute_map = {
        'secret_ref': {'key': 'secretRef', 'type': 'str'},
        'trigger_parameter': {'key': 'triggerParameter', 'type': 'str'},
    }

    def __init__(self, *, secret_ref: str=None, trigger_parameter: str=None, **kwargs) -> None:
        super(WorkerAppScaleRuleAuth, self).__init__(**kwargs)
        self.secret_ref = secret_ref
        self.trigger_parameter = trigger_parameter


class WorkerAppsConfiguration(Model):
    """Configuration required deploy Kube Environment Dedicated
    to Worker Apps.
    Create request is not accepted, if ArcConfiguration or AksResourceId is
    provided
    with WorkerAppsConfiguration.

    :param subnet_resource_id: VNET Subnet resource ID
    :type subnet_resource_id: str
    :param aci_subnet_resource_name: ACI subnet name
    :type aci_subnet_resource_name: str
    :param dapr_ai_instrumentation_key: Azure Monitor instrumentation key used
     by Dapr
    :type dapr_ai_instrumentation_key: str
    """

    _attribute_map = {
        'subnet_resource_id': {'key': 'subnetResourceId', 'type': 'str'},
        'aci_subnet_resource_name': {'key': 'aciSubnetResourceName', 'type': 'str'},
        'dapr_ai_instrumentation_key': {'key': 'daprAIInstrumentationKey', 'type': 'str'},
    }

    def __init__(self, *, subnet_resource_id: str=None, aci_subnet_resource_name: str=None, dapr_ai_instrumentation_key: str=None, **kwargs) -> None:
        super(WorkerAppsConfiguration, self).__init__(**kwargs)
        self.subnet_resource_id = subnet_resource_id
        self.aci_subnet_resource_name = aci_subnet_resource_name
        self.dapr_ai_instrumentation_key = dapr_ai_instrumentation_key


class WorkerAppSecret(Model):
    """Worker App Secret.

    :param name: Secret Name.
    :type name: str
    :param value: Secret Value.
    :type value: str
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'value': {'key': 'value', 'type': 'str'},
    }

    def __init__(self, *, name: str=None, value: str=None, **kwargs) -> None:
        super(WorkerAppSecret, self).__init__(**kwargs)
        self.name = name
        self.value = value


class WorkerAppTemplate(Model):
    """Worker App versioned application definition.
    Defines the desired state of an immutable revision.
    Any changes to this section Will result in a new revision being created.

    :param revision_suffix: User friendly suffix that is appended to the
     revision name
    :type revision_suffix: str
    :param containers: List of container definitions for the Worker App.
    :type containers:
     list[~azure.mgmt.web.v2021_02_01.models.WorkerAppContainer]
    :param scale: Scaling properties for the Worker App.
    :type scale: ~azure.mgmt.web.v2021_02_01.models.WorkerAppScale
    :param dapr: Dapr configuration for the Worker App.
    :type dapr: ~azure.mgmt.web.v2021_02_01.models.WorkerAppDapr
    """

    _attribute_map = {
        'revision_suffix': {'key': 'revisionSuffix', 'type': 'str'},
        'containers': {'key': 'containers', 'type': '[WorkerAppContainer]'},
        'scale': {'key': 'scale', 'type': 'WorkerAppScale'},
        'dapr': {'key': 'dapr', 'type': 'WorkerAppDapr'},
    }

    def __init__(self, *, revision_suffix: str=None, containers=None, scale=None, dapr=None, **kwargs) -> None:
        super(WorkerAppTemplate, self).__init__(**kwargs)
        self.revision_suffix = revision_suffix
        self.containers = containers
        self.scale = scale
        self.dapr = dapr


class WorkerAppTrafficWeight(Model):
    """Traffic weight assigned to a revision.

    :param revision_name: Name of a revision
    :type revision_name: str
    :param weight: Traffic weight assigned to a revision
    :type weight: int
    :param latest_revision: Indicates that the traffic weight belongs to a
     latest stable revision. Default value: False .
    :type latest_revision: bool
    """

    _attribute_map = {
        'revision_name': {'key': 'revisionName', 'type': 'str'},
        'weight': {'key': 'weight', 'type': 'int'},
        'latest_revision': {'key': 'latestRevision', 'type': 'bool'},
    }

    def __init__(self, *, revision_name: str=None, weight: int=None, latest_revision: bool=False, **kwargs) -> None:
        super(WorkerAppTrafficWeight, self).__init__(**kwargs)
        self.revision_name = revision_name
        self.weight = weight
        self.latest_revision = latest_revision
